/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIX509Cert18Branch.idl
 */

#ifndef __gen_nsIX509Cert18Branch_h__
#define __gen_nsIX509Cert18Branch_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIX509Cert; /* forward declaration */


/* starting interface:    nsIX509Cert18Branch */
#define NS_IX509CERT18BRANCH_IID_STR "b02aabbc-f444-4639-8021-52c73b8f1b24"

#define NS_IX509CERT18BRANCH_IID \
  {0xb02aabbc, 0xf444, 0x4639, \
    { 0x80, 0x21, 0x52, 0xc7, 0x3b, 0x8f, 0x1b, 0x24 }}

/**
 * Extending nsIX509Cert
 * 
 * TODO: nsIX509Cert3 should be derived from nsIX509Cert2
 *       (and nsIX509Cert2 derived from nsIX509Cert)
 */
class NS_NO_VTABLE nsIX509Cert18Branch : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IX509CERT18BRANCH_IID)

  /**
   * Returns a count of valid names, and a string with all
   * valid names (or patterns or IP addresses)
   * separated by " , " (space comma space).
   */
  /* PRUint32 getValidNames (out wstring names); */
  NS_IMETHOD GetValidNames(PRUnichar **names, PRUint32 *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIX509CERT18BRANCH \
  NS_IMETHOD GetValidNames(PRUnichar **names, PRUint32 *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIX509CERT18BRANCH(_to) \
  NS_IMETHOD GetValidNames(PRUnichar **names, PRUint32 *_retval) { return _to GetValidNames(names, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIX509CERT18BRANCH(_to) \
  NS_IMETHOD GetValidNames(PRUnichar **names, PRUint32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValidNames(names, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsX509Cert18Branch : public nsIX509Cert18Branch
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIX509CERT18BRANCH

  nsX509Cert18Branch();

private:
  ~nsX509Cert18Branch();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsX509Cert18Branch, nsIX509Cert18Branch)

nsX509Cert18Branch::nsX509Cert18Branch()
{
  /* member initializers and constructor code */
}

nsX509Cert18Branch::~nsX509Cert18Branch()
{
  /* destructor code */
}

/* PRUint32 getValidNames (out wstring names); */
NS_IMETHODIMP nsX509Cert18Branch::GetValidNames(PRUnichar **names, PRUint32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIX509Cert18Branch_h__ */
