/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgWindow.idl
 */

#ifndef __gen_nsIMsgWindow_h__
#define __gen_nsIMsgWindow_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgStatusFeedback_h__
#include "nsIMsgStatusFeedback.h"
#endif

#ifndef __gen_nsIMsgFolder_h__
#include "nsIMsgFolder.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsITransactionManager; /* forward declaration */

class nsIDocShell; /* forward declaration */

class nsIDOMWindowInternal; /* forward declaration */

class nsIMsgHeaderSink; /* forward declaration */

class nsIPrompt; /* forward declaration */

class nsIAuthPrompt; /* forward declaration */


/* starting interface:    nsIMsgMessagePaneController */
#define NS_IMSGMESSAGEPANECONTROLLER_IID_STR "923de63d-eeb9-4574-850b-322c1a4667ed"

#define NS_IMSGMESSAGEPANECONTROLLER_IID \
  {0x923de63d, 0xeeb9, 0x4574, \
    { 0x85, 0x0b, 0x32, 0x2c, 0x1a, 0x46, 0x67, 0xed }}

class NS_NO_VTABLE nsIMsgMessagePaneController : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGMESSAGEPANECONTROLLER_IID)

  /* void clearMsgPane (); */
  NS_IMETHOD ClearMsgPane(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGMESSAGEPANECONTROLLER \
  NS_IMETHOD ClearMsgPane(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGMESSAGEPANECONTROLLER(_to) \
  NS_IMETHOD ClearMsgPane(void) { return _to ClearMsgPane(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGMESSAGEPANECONTROLLER(_to) \
  NS_IMETHOD ClearMsgPane(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearMsgPane(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgMessagePaneController : public nsIMsgMessagePaneController
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGMESSAGEPANECONTROLLER

  nsMsgMessagePaneController();

private:
  ~nsMsgMessagePaneController();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgMessagePaneController, nsIMsgMessagePaneController)

nsMsgMessagePaneController::nsMsgMessagePaneController()
{
  /* member initializers and constructor code */
}

nsMsgMessagePaneController::~nsMsgMessagePaneController()
{
  /* destructor code */
}

/* void clearMsgPane (); */
NS_IMETHODIMP nsMsgMessagePaneController::ClearMsgPane()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIMsgWindow */
#define NS_IMSGWINDOW_IID_STR "bce0ab71-11ff-428e-9edc-69abad73b697"

#define NS_IMSGWINDOW_IID \
  {0xbce0ab71, 0x11ff, 0x428e, \
    { 0x9e, 0xdc, 0x69, 0xab, 0xad, 0x73, 0xb6, 0x97 }}

class NS_NO_VTABLE nsIMsgWindow : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGWINDOW_IID)

  /* attribute nsIMsgMessagePaneController messagePaneController; */
  NS_IMETHOD GetMessagePaneController(nsIMsgMessagePaneController * *aMessagePaneController) = 0;
  NS_IMETHOD SetMessagePaneController(nsIMsgMessagePaneController * aMessagePaneController) = 0;

  /* attribute nsIMsgStatusFeedback statusFeedback; */
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback) = 0;
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback * aStatusFeedback) = 0;

  /* attribute nsIMsgHeaderSink msgHeaderSink; */
  NS_IMETHOD GetMsgHeaderSink(nsIMsgHeaderSink * *aMsgHeaderSink) = 0;
  NS_IMETHOD SetMsgHeaderSink(nsIMsgHeaderSink * aMsgHeaderSink) = 0;

  /* attribute nsITransactionManager transactionManager; */
  NS_IMETHOD GetTransactionManager(nsITransactionManager * *aTransactionManager) = 0;
  NS_IMETHOD SetTransactionManager(nsITransactionManager * aTransactionManager) = 0;

  /* attribute nsIMsgFolder openFolder; */
  NS_IMETHOD GetOpenFolder(nsIMsgFolder * *aOpenFolder) = 0;
  NS_IMETHOD SetOpenFolder(nsIMsgFolder * aOpenFolder) = 0;

  /* attribute nsIDocShell rootDocShell; */
  NS_IMETHOD GetRootDocShell(nsIDocShell * *aRootDocShell) = 0;
  NS_IMETHOD SetRootDocShell(nsIDocShell * aRootDocShell) = 0;

  /* void displayHTMLInMessagePane (in wstring title, in wstring body, in boolean clearMsgHdr); */
  NS_IMETHOD DisplayHTMLInMessagePane(const PRUnichar *title, const PRUnichar *body, PRBool clearMsgHdr) = 0;

  /* readonly attribute nsIPrompt promptDialog; */
  NS_IMETHOD GetPromptDialog(nsIPrompt * *aPromptDialog) = 0;

  /* attribute string mailCharacterSet; */
  NS_IMETHOD GetMailCharacterSet(char * *aMailCharacterSet) = 0;
  NS_IMETHOD SetMailCharacterSet(const char * aMailCharacterSet) = 0;

  /* attribute boolean charsetOverride; */
  NS_IMETHOD GetCharsetOverride(PRBool *aCharsetOverride) = 0;
  NS_IMETHOD SetCharsetOverride(PRBool aCharsetOverride) = 0;

  /* attribute boolean stopped; */
  NS_IMETHOD GetStopped(PRBool *aStopped) = 0;
  NS_IMETHOD SetStopped(PRBool aStopped) = 0;

  /* void SetDOMWindow (in nsIDOMWindowInternal window); */
  NS_IMETHOD SetDOMWindow(nsIDOMWindowInternal *window) = 0;

  /* void StopUrls (); */
  NS_IMETHOD StopUrls(void) = 0;

  /* void SelectFolder (in string folderUri); */
  NS_IMETHOD SelectFolder(const char *folderUri) = 0;

  /* void SelectMessage (in string messageUri); */
  NS_IMETHOD SelectMessage(const char *messageUri) = 0;

  /* void closeWindow (); */
  NS_IMETHOD CloseWindow(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGWINDOW \
  NS_IMETHOD GetMessagePaneController(nsIMsgMessagePaneController * *aMessagePaneController); \
  NS_IMETHOD SetMessagePaneController(nsIMsgMessagePaneController * aMessagePaneController); \
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback); \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback * aStatusFeedback); \
  NS_IMETHOD GetMsgHeaderSink(nsIMsgHeaderSink * *aMsgHeaderSink); \
  NS_IMETHOD SetMsgHeaderSink(nsIMsgHeaderSink * aMsgHeaderSink); \
  NS_IMETHOD GetTransactionManager(nsITransactionManager * *aTransactionManager); \
  NS_IMETHOD SetTransactionManager(nsITransactionManager * aTransactionManager); \
  NS_IMETHOD GetOpenFolder(nsIMsgFolder * *aOpenFolder); \
  NS_IMETHOD SetOpenFolder(nsIMsgFolder * aOpenFolder); \
  NS_IMETHOD GetRootDocShell(nsIDocShell * *aRootDocShell); \
  NS_IMETHOD SetRootDocShell(nsIDocShell * aRootDocShell); \
  NS_IMETHOD DisplayHTMLInMessagePane(const PRUnichar *title, const PRUnichar *body, PRBool clearMsgHdr); \
  NS_IMETHOD GetPromptDialog(nsIPrompt * *aPromptDialog); \
  NS_IMETHOD GetMailCharacterSet(char * *aMailCharacterSet); \
  NS_IMETHOD SetMailCharacterSet(const char * aMailCharacterSet); \
  NS_IMETHOD GetCharsetOverride(PRBool *aCharsetOverride); \
  NS_IMETHOD SetCharsetOverride(PRBool aCharsetOverride); \
  NS_IMETHOD GetStopped(PRBool *aStopped); \
  NS_IMETHOD SetStopped(PRBool aStopped); \
  NS_IMETHOD SetDOMWindow(nsIDOMWindowInternal *window); \
  NS_IMETHOD StopUrls(void); \
  NS_IMETHOD SelectFolder(const char *folderUri); \
  NS_IMETHOD SelectMessage(const char *messageUri); \
  NS_IMETHOD CloseWindow(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGWINDOW(_to) \
  NS_IMETHOD GetMessagePaneController(nsIMsgMessagePaneController * *aMessagePaneController) { return _to GetMessagePaneController(aMessagePaneController); } \
  NS_IMETHOD SetMessagePaneController(nsIMsgMessagePaneController * aMessagePaneController) { return _to SetMessagePaneController(aMessagePaneController); } \
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback) { return _to GetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback * aStatusFeedback) { return _to SetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD GetMsgHeaderSink(nsIMsgHeaderSink * *aMsgHeaderSink) { return _to GetMsgHeaderSink(aMsgHeaderSink); } \
  NS_IMETHOD SetMsgHeaderSink(nsIMsgHeaderSink * aMsgHeaderSink) { return _to SetMsgHeaderSink(aMsgHeaderSink); } \
  NS_IMETHOD GetTransactionManager(nsITransactionManager * *aTransactionManager) { return _to GetTransactionManager(aTransactionManager); } \
  NS_IMETHOD SetTransactionManager(nsITransactionManager * aTransactionManager) { return _to SetTransactionManager(aTransactionManager); } \
  NS_IMETHOD GetOpenFolder(nsIMsgFolder * *aOpenFolder) { return _to GetOpenFolder(aOpenFolder); } \
  NS_IMETHOD SetOpenFolder(nsIMsgFolder * aOpenFolder) { return _to SetOpenFolder(aOpenFolder); } \
  NS_IMETHOD GetRootDocShell(nsIDocShell * *aRootDocShell) { return _to GetRootDocShell(aRootDocShell); } \
  NS_IMETHOD SetRootDocShell(nsIDocShell * aRootDocShell) { return _to SetRootDocShell(aRootDocShell); } \
  NS_IMETHOD DisplayHTMLInMessagePane(const PRUnichar *title, const PRUnichar *body, PRBool clearMsgHdr) { return _to DisplayHTMLInMessagePane(title, body, clearMsgHdr); } \
  NS_IMETHOD GetPromptDialog(nsIPrompt * *aPromptDialog) { return _to GetPromptDialog(aPromptDialog); } \
  NS_IMETHOD GetMailCharacterSet(char * *aMailCharacterSet) { return _to GetMailCharacterSet(aMailCharacterSet); } \
  NS_IMETHOD SetMailCharacterSet(const char * aMailCharacterSet) { return _to SetMailCharacterSet(aMailCharacterSet); } \
  NS_IMETHOD GetCharsetOverride(PRBool *aCharsetOverride) { return _to GetCharsetOverride(aCharsetOverride); } \
  NS_IMETHOD SetCharsetOverride(PRBool aCharsetOverride) { return _to SetCharsetOverride(aCharsetOverride); } \
  NS_IMETHOD GetStopped(PRBool *aStopped) { return _to GetStopped(aStopped); } \
  NS_IMETHOD SetStopped(PRBool aStopped) { return _to SetStopped(aStopped); } \
  NS_IMETHOD SetDOMWindow(nsIDOMWindowInternal *window) { return _to SetDOMWindow(window); } \
  NS_IMETHOD StopUrls(void) { return _to StopUrls(); } \
  NS_IMETHOD SelectFolder(const char *folderUri) { return _to SelectFolder(folderUri); } \
  NS_IMETHOD SelectMessage(const char *messageUri) { return _to SelectMessage(messageUri); } \
  NS_IMETHOD CloseWindow(void) { return _to CloseWindow(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGWINDOW(_to) \
  NS_IMETHOD GetMessagePaneController(nsIMsgMessagePaneController * *aMessagePaneController) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessagePaneController(aMessagePaneController); } \
  NS_IMETHOD SetMessagePaneController(nsIMsgMessagePaneController * aMessagePaneController) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessagePaneController(aMessagePaneController); } \
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback * aStatusFeedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD GetMsgHeaderSink(nsIMsgHeaderSink * *aMsgHeaderSink) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgHeaderSink(aMsgHeaderSink); } \
  NS_IMETHOD SetMsgHeaderSink(nsIMsgHeaderSink * aMsgHeaderSink) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgHeaderSink(aMsgHeaderSink); } \
  NS_IMETHOD GetTransactionManager(nsITransactionManager * *aTransactionManager) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTransactionManager(aTransactionManager); } \
  NS_IMETHOD SetTransactionManager(nsITransactionManager * aTransactionManager) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTransactionManager(aTransactionManager); } \
  NS_IMETHOD GetOpenFolder(nsIMsgFolder * *aOpenFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOpenFolder(aOpenFolder); } \
  NS_IMETHOD SetOpenFolder(nsIMsgFolder * aOpenFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOpenFolder(aOpenFolder); } \
  NS_IMETHOD GetRootDocShell(nsIDocShell * *aRootDocShell) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRootDocShell(aRootDocShell); } \
  NS_IMETHOD SetRootDocShell(nsIDocShell * aRootDocShell) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRootDocShell(aRootDocShell); } \
  NS_IMETHOD DisplayHTMLInMessagePane(const PRUnichar *title, const PRUnichar *body, PRBool clearMsgHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->DisplayHTMLInMessagePane(title, body, clearMsgHdr); } \
  NS_IMETHOD GetPromptDialog(nsIPrompt * *aPromptDialog) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPromptDialog(aPromptDialog); } \
  NS_IMETHOD GetMailCharacterSet(char * *aMailCharacterSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailCharacterSet(aMailCharacterSet); } \
  NS_IMETHOD SetMailCharacterSet(const char * aMailCharacterSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailCharacterSet(aMailCharacterSet); } \
  NS_IMETHOD GetCharsetOverride(PRBool *aCharsetOverride) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharsetOverride(aCharsetOverride); } \
  NS_IMETHOD SetCharsetOverride(PRBool aCharsetOverride) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharsetOverride(aCharsetOverride); } \
  NS_IMETHOD GetStopped(PRBool *aStopped) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStopped(aStopped); } \
  NS_IMETHOD SetStopped(PRBool aStopped) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStopped(aStopped); } \
  NS_IMETHOD SetDOMWindow(nsIDOMWindowInternal *window) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDOMWindow(window); } \
  NS_IMETHOD StopUrls(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->StopUrls(); } \
  NS_IMETHOD SelectFolder(const char *folderUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectFolder(folderUri); } \
  NS_IMETHOD SelectMessage(const char *messageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectMessage(messageUri); } \
  NS_IMETHOD CloseWindow(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloseWindow(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgWindow : public nsIMsgWindow
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGWINDOW

  nsMsgWindow();

private:
  ~nsMsgWindow();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgWindow, nsIMsgWindow)

nsMsgWindow::nsMsgWindow()
{
  /* member initializers and constructor code */
}

nsMsgWindow::~nsMsgWindow()
{
  /* destructor code */
}

/* attribute nsIMsgMessagePaneController messagePaneController; */
NS_IMETHODIMP nsMsgWindow::GetMessagePaneController(nsIMsgMessagePaneController * *aMessagePaneController)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetMessagePaneController(nsIMsgMessagePaneController * aMessagePaneController)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgStatusFeedback statusFeedback; */
NS_IMETHODIMP nsMsgWindow::GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetStatusFeedback(nsIMsgStatusFeedback * aStatusFeedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgHeaderSink msgHeaderSink; */
NS_IMETHODIMP nsMsgWindow::GetMsgHeaderSink(nsIMsgHeaderSink * *aMsgHeaderSink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetMsgHeaderSink(nsIMsgHeaderSink * aMsgHeaderSink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsITransactionManager transactionManager; */
NS_IMETHODIMP nsMsgWindow::GetTransactionManager(nsITransactionManager * *aTransactionManager)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetTransactionManager(nsITransactionManager * aTransactionManager)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgFolder openFolder; */
NS_IMETHODIMP nsMsgWindow::GetOpenFolder(nsIMsgFolder * *aOpenFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetOpenFolder(nsIMsgFolder * aOpenFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIDocShell rootDocShell; */
NS_IMETHODIMP nsMsgWindow::GetRootDocShell(nsIDocShell * *aRootDocShell)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetRootDocShell(nsIDocShell * aRootDocShell)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void displayHTMLInMessagePane (in wstring title, in wstring body, in boolean clearMsgHdr); */
NS_IMETHODIMP nsMsgWindow::DisplayHTMLInMessagePane(const PRUnichar *title, const PRUnichar *body, PRBool clearMsgHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIPrompt promptDialog; */
NS_IMETHODIMP nsMsgWindow::GetPromptDialog(nsIPrompt * *aPromptDialog)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string mailCharacterSet; */
NS_IMETHODIMP nsMsgWindow::GetMailCharacterSet(char * *aMailCharacterSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetMailCharacterSet(const char * aMailCharacterSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean charsetOverride; */
NS_IMETHODIMP nsMsgWindow::GetCharsetOverride(PRBool *aCharsetOverride)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetCharsetOverride(PRBool aCharsetOverride)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean stopped; */
NS_IMETHODIMP nsMsgWindow::GetStopped(PRBool *aStopped)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgWindow::SetStopped(PRBool aStopped)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetDOMWindow (in nsIDOMWindowInternal window); */
NS_IMETHODIMP nsMsgWindow::SetDOMWindow(nsIDOMWindowInternal *window)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void StopUrls (); */
NS_IMETHODIMP nsMsgWindow::StopUrls()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SelectFolder (in string folderUri); */
NS_IMETHODIMP nsMsgWindow::SelectFolder(const char *folderUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SelectMessage (in string messageUri); */
NS_IMETHODIMP nsMsgWindow::SelectMessage(const char *messageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void closeWindow (); */
NS_IMETHODIMP nsMsgWindow::CloseWindow()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIMsgWindowCommands */
#define NS_IMSGWINDOWCOMMANDS_IID_STR "fad93c80-1ac6-11d4-a8f6-006097222b83"

#define NS_IMSGWINDOWCOMMANDS_IID \
  {0xfad93c80, 0x1ac6, 0x11d4, \
    { 0xa8, 0xf6, 0x00, 0x60, 0x97, 0x22, 0x2b, 0x83 }}

class NS_NO_VTABLE nsIMsgWindowCommands : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGWINDOWCOMMANDS_IID)

  /* void SelectFolder (in string folderUri); */
  NS_IMETHOD SelectFolder(const char *folderUri) = 0;

  /* void SelectMessage (in string messageUri); */
  NS_IMETHOD SelectMessage(const char *messageUri) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGWINDOWCOMMANDS \
  NS_IMETHOD SelectFolder(const char *folderUri); \
  NS_IMETHOD SelectMessage(const char *messageUri); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGWINDOWCOMMANDS(_to) \
  NS_IMETHOD SelectFolder(const char *folderUri) { return _to SelectFolder(folderUri); } \
  NS_IMETHOD SelectMessage(const char *messageUri) { return _to SelectMessage(messageUri); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGWINDOWCOMMANDS(_to) \
  NS_IMETHOD SelectFolder(const char *folderUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectFolder(folderUri); } \
  NS_IMETHOD SelectMessage(const char *messageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectMessage(messageUri); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgWindowCommands : public nsIMsgWindowCommands
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGWINDOWCOMMANDS

  nsMsgWindowCommands();

private:
  ~nsMsgWindowCommands();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgWindowCommands, nsIMsgWindowCommands)

nsMsgWindowCommands::nsMsgWindowCommands()
{
  /* member initializers and constructor code */
}

nsMsgWindowCommands::~nsMsgWindowCommands()
{
  /* destructor code */
}

/* void SelectFolder (in string folderUri); */
NS_IMETHODIMP nsMsgWindowCommands::SelectFolder(const char *folderUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SelectMessage (in string messageUri); */
NS_IMETHODIMP nsMsgWindowCommands::SelectMessage(const char *messageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgWindow_h__ */
