/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportAddressBooks.idl
 */

#ifndef __gen_nsIImportAddressBooks_h__
#define __gen_nsIImportAddressBooks_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */

class nsISupportsArray; /* forward declaration */

class nsIImportABDescriptor; /* forward declaration */

class nsIOutputStream; /* forward declaration */

class nsIAddrDatabase; /* forward declaration */

class nsIImportFieldMap; /* forward declaration */


/* starting interface:    nsIImportAddressBooks */
#define NS_IIMPORTADDRESSBOOKS_IID_STR "3fe29be0-3539-11d3-a206-00a0cc26da63"

#define NS_IIMPORTADDRESSBOOKS_IID \
  {0x3fe29be0, 0x3539, 0x11d3, \
    { 0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63 }}

class NS_NO_VTABLE nsIImportAddressBooks : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMPORTADDRESSBOOKS_IID)

  /* PRBool GetSupportsMultiple (); */
  NS_IMETHOD GetSupportsMultiple(PRBool *_retval) = 0;

  /* PRBool GetAutoFind (out wstring description); */
  NS_IMETHOD GetAutoFind(PRUnichar **description, PRBool *_retval) = 0;

  /* PRBool GetNeedsFieldMap (in nsIFileSpec location); */
  NS_IMETHOD GetNeedsFieldMap(nsIFileSpec *location, PRBool *_retval) = 0;

  /* void GetDefaultLocation (out nsIFileSpec location, out boolean found, out boolean userVerify); */
  NS_IMETHOD GetDefaultLocation(nsIFileSpec **location, PRBool *found, PRBool *userVerify) = 0;

  /* nsISupportsArray FindAddressBooks (in nsIFileSpec location); */
  NS_IMETHOD FindAddressBooks(nsIFileSpec *location, nsISupportsArray **_retval) = 0;

  /* void InitFieldMap (in nsIFileSpec location, in nsIImportFieldMap fieldMap); */
  NS_IMETHOD InitFieldMap(nsIFileSpec *location, nsIImportFieldMap *fieldMap) = 0;

  /* void ImportAddressBook (in nsIImportABDescriptor source, in nsIAddrDatabase destination, in nsIImportFieldMap fieldMap, in boolean isAddrLocHome, out wstring errorLog, out wstring successLog, out boolean fatalError); */
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *source, nsIAddrDatabase *destination, nsIImportFieldMap *fieldMap, PRBool isAddrLocHome, PRUnichar **errorLog, PRUnichar **successLog, PRBool *fatalError) = 0;

  /* unsigned long GetImportProgress (); */
  NS_IMETHOD GetImportProgress(PRUint32 *_retval) = 0;

  /* void SetSampleLocation (in nsIFileSpec location); */
  NS_IMETHOD SetSampleLocation(nsIFileSpec *location) = 0;

  /* wstring GetSampleData (in long recordNumber, out boolean recordExists); */
  NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists, PRUnichar **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTADDRESSBOOKS \
  NS_IMETHOD GetSupportsMultiple(PRBool *_retval); \
  NS_IMETHOD GetAutoFind(PRUnichar **description, PRBool *_retval); \
  NS_IMETHOD GetNeedsFieldMap(nsIFileSpec *location, PRBool *_retval); \
  NS_IMETHOD GetDefaultLocation(nsIFileSpec **location, PRBool *found, PRBool *userVerify); \
  NS_IMETHOD FindAddressBooks(nsIFileSpec *location, nsISupportsArray **_retval); \
  NS_IMETHOD InitFieldMap(nsIFileSpec *location, nsIImportFieldMap *fieldMap); \
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *source, nsIAddrDatabase *destination, nsIImportFieldMap *fieldMap, PRBool isAddrLocHome, PRUnichar **errorLog, PRUnichar **successLog, PRBool *fatalError); \
  NS_IMETHOD GetImportProgress(PRUint32 *_retval); \
  NS_IMETHOD SetSampleLocation(nsIFileSpec *location); \
  NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists, PRUnichar **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTADDRESSBOOKS(_to) \
  NS_IMETHOD GetSupportsMultiple(PRBool *_retval) { return _to GetSupportsMultiple(_retval); } \
  NS_IMETHOD GetAutoFind(PRUnichar **description, PRBool *_retval) { return _to GetAutoFind(description, _retval); } \
  NS_IMETHOD GetNeedsFieldMap(nsIFileSpec *location, PRBool *_retval) { return _to GetNeedsFieldMap(location, _retval); } \
  NS_IMETHOD GetDefaultLocation(nsIFileSpec **location, PRBool *found, PRBool *userVerify) { return _to GetDefaultLocation(location, found, userVerify); } \
  NS_IMETHOD FindAddressBooks(nsIFileSpec *location, nsISupportsArray **_retval) { return _to FindAddressBooks(location, _retval); } \
  NS_IMETHOD InitFieldMap(nsIFileSpec *location, nsIImportFieldMap *fieldMap) { return _to InitFieldMap(location, fieldMap); } \
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *source, nsIAddrDatabase *destination, nsIImportFieldMap *fieldMap, PRBool isAddrLocHome, PRUnichar **errorLog, PRUnichar **successLog, PRBool *fatalError) { return _to ImportAddressBook(source, destination, fieldMap, isAddrLocHome, errorLog, successLog, fatalError); } \
  NS_IMETHOD GetImportProgress(PRUint32 *_retval) { return _to GetImportProgress(_retval); } \
  NS_IMETHOD SetSampleLocation(nsIFileSpec *location) { return _to SetSampleLocation(location); } \
  NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists, PRUnichar **_retval) { return _to GetSampleData(recordNumber, recordExists, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTADDRESSBOOKS(_to) \
  NS_IMETHOD GetSupportsMultiple(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportsMultiple(_retval); } \
  NS_IMETHOD GetAutoFind(PRUnichar **description, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAutoFind(description, _retval); } \
  NS_IMETHOD GetNeedsFieldMap(nsIFileSpec *location, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsFieldMap(location, _retval); } \
  NS_IMETHOD GetDefaultLocation(nsIFileSpec **location, PRBool *found, PRBool *userVerify) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultLocation(location, found, userVerify); } \
  NS_IMETHOD FindAddressBooks(nsIFileSpec *location, nsISupportsArray **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindAddressBooks(location, _retval); } \
  NS_IMETHOD InitFieldMap(nsIFileSpec *location, nsIImportFieldMap *fieldMap) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitFieldMap(location, fieldMap); } \
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *source, nsIAddrDatabase *destination, nsIImportFieldMap *fieldMap, PRBool isAddrLocHome, PRUnichar **errorLog, PRUnichar **successLog, PRBool *fatalError) { return !_to ? NS_ERROR_NULL_POINTER : _to->ImportAddressBook(source, destination, fieldMap, isAddrLocHome, errorLog, successLog, fatalError); } \
  NS_IMETHOD GetImportProgress(PRUint32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImportProgress(_retval); } \
  NS_IMETHOD SetSampleLocation(nsIFileSpec *location) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSampleLocation(location); } \
  NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists, PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSampleData(recordNumber, recordExists, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportAddressBooks : public nsIImportAddressBooks
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTADDRESSBOOKS

  nsImportAddressBooks();

private:
  ~nsImportAddressBooks();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportAddressBooks, nsIImportAddressBooks)

nsImportAddressBooks::nsImportAddressBooks()
{
  /* member initializers and constructor code */
}

nsImportAddressBooks::~nsImportAddressBooks()
{
  /* destructor code */
}

/* PRBool GetSupportsMultiple (); */
NS_IMETHODIMP nsImportAddressBooks::GetSupportsMultiple(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* PRBool GetAutoFind (out wstring description); */
NS_IMETHODIMP nsImportAddressBooks::GetAutoFind(PRUnichar **description, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* PRBool GetNeedsFieldMap (in nsIFileSpec location); */
NS_IMETHODIMP nsImportAddressBooks::GetNeedsFieldMap(nsIFileSpec *location, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetDefaultLocation (out nsIFileSpec location, out boolean found, out boolean userVerify); */
NS_IMETHODIMP nsImportAddressBooks::GetDefaultLocation(nsIFileSpec **location, PRBool *found, PRBool *userVerify)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupportsArray FindAddressBooks (in nsIFileSpec location); */
NS_IMETHODIMP nsImportAddressBooks::FindAddressBooks(nsIFileSpec *location, nsISupportsArray **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void InitFieldMap (in nsIFileSpec location, in nsIImportFieldMap fieldMap); */
NS_IMETHODIMP nsImportAddressBooks::InitFieldMap(nsIFileSpec *location, nsIImportFieldMap *fieldMap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ImportAddressBook (in nsIImportABDescriptor source, in nsIAddrDatabase destination, in nsIImportFieldMap fieldMap, in boolean isAddrLocHome, out wstring errorLog, out wstring successLog, out boolean fatalError); */
NS_IMETHODIMP nsImportAddressBooks::ImportAddressBook(nsIImportABDescriptor *source, nsIAddrDatabase *destination, nsIImportFieldMap *fieldMap, PRBool isAddrLocHome, PRUnichar **errorLog, PRUnichar **successLog, PRBool *fatalError)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long GetImportProgress (); */
NS_IMETHODIMP nsImportAddressBooks::GetImportProgress(PRUint32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetSampleLocation (in nsIFileSpec location); */
NS_IMETHODIMP nsImportAddressBooks::SetSampleLocation(nsIFileSpec *location)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetSampleData (in long recordNumber, out boolean recordExists); */
NS_IMETHODIMP nsImportAddressBooks::GetSampleData(PRInt32 recordNumber, PRBool *recordExists, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImportAddressBooks_h__ */
