/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgQuote.idl
 */

#ifndef __gen_nsIMsgQuote_h__
#define __gen_nsIMsgQuote_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIStreamListener_h__
#include "nsIStreamListener.h"
#endif

#ifndef __gen_nsIChannel_h__
#include "nsIChannel.h"
#endif

#ifndef __gen_nsIMimeStreamConverter_h__
#include "nsIMimeStreamConverter.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgQuote */
#define NS_IMSGQUOTE_IID_STR "1c7abf0c-21e5-11d3-8ef1-00a024a7d144"

#define NS_IMSGQUOTE_IID \
  {0x1c7abf0c, 0x21e5, 0x11d3, \
    { 0x8e, 0xf1, 0x00, 0xa0, 0x24, 0xa7, 0xd1, 0x44 }}

class NS_NO_VTABLE nsIMsgQuote : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGQUOTE_IID)

  /* void QuoteMessage (in string msgURI, in boolean quoteHeaders, in nsIStreamListener aStreamListener, in string aCharset, in boolean headersOnly); */
  NS_IMETHOD QuoteMessage(const char *msgURI, PRBool quoteHeaders, nsIStreamListener *aStreamListener, const char *aCharset, PRBool headersOnly) = 0;

  /* readonly attribute nsIMimeStreamConverterListener quoteListener; */
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener) = 0;

  /* readonly attribute nsIChannel quoteChannel; */
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel) = 0;

  /* readonly attribute nsIStreamListener streamListener; */
  NS_IMETHOD GetStreamListener(nsIStreamListener * *aStreamListener) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGQUOTE \
  NS_IMETHOD QuoteMessage(const char *msgURI, PRBool quoteHeaders, nsIStreamListener *aStreamListener, const char *aCharset, PRBool headersOnly); \
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener); \
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel); \
  NS_IMETHOD GetStreamListener(nsIStreamListener * *aStreamListener); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGQUOTE(_to) \
  NS_IMETHOD QuoteMessage(const char *msgURI, PRBool quoteHeaders, nsIStreamListener *aStreamListener, const char *aCharset, PRBool headersOnly) { return _to QuoteMessage(msgURI, quoteHeaders, aStreamListener, aCharset, headersOnly); } \
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener) { return _to GetQuoteListener(aQuoteListener); } \
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel) { return _to GetQuoteChannel(aQuoteChannel); } \
  NS_IMETHOD GetStreamListener(nsIStreamListener * *aStreamListener) { return _to GetStreamListener(aStreamListener); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGQUOTE(_to) \
  NS_IMETHOD QuoteMessage(const char *msgURI, PRBool quoteHeaders, nsIStreamListener *aStreamListener, const char *aCharset, PRBool headersOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->QuoteMessage(msgURI, quoteHeaders, aStreamListener, aCharset, headersOnly); } \
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetQuoteListener(aQuoteListener); } \
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetQuoteChannel(aQuoteChannel); } \
  NS_IMETHOD GetStreamListener(nsIStreamListener * *aStreamListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStreamListener(aStreamListener); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgQuote : public nsIMsgQuote
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGQUOTE

  nsMsgQuote();

private:
  ~nsMsgQuote();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgQuote, nsIMsgQuote)

nsMsgQuote::nsMsgQuote()
{
  /* member initializers and constructor code */
}

nsMsgQuote::~nsMsgQuote()
{
  /* destructor code */
}

/* void QuoteMessage (in string msgURI, in boolean quoteHeaders, in nsIStreamListener aStreamListener, in string aCharset, in boolean headersOnly); */
NS_IMETHODIMP nsMsgQuote::QuoteMessage(const char *msgURI, PRBool quoteHeaders, nsIStreamListener *aStreamListener, const char *aCharset, PRBool headersOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMimeStreamConverterListener quoteListener; */
NS_IMETHODIMP nsMsgQuote::GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIChannel quoteChannel; */
NS_IMETHODIMP nsMsgQuote::GetQuoteChannel(nsIChannel * *aQuoteChannel)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIStreamListener streamListener; */
NS_IMETHODIMP nsMsgQuote::GetStreamListener(nsIStreamListener * *aStreamListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIMsgQuoteListener */
#define NS_IMSGQUOTELISTENER_IID_STR "1ec75ad9-88de-11d3-989d-001083010e9b"

#define NS_IMSGQUOTELISTENER_IID \
  {0x1ec75ad9, 0x88de, 0x11d3, \
    { 0x98, 0x9d, 0x00, 0x10, 0x83, 0x01, 0x0e, 0x9b }}

class NS_NO_VTABLE nsIMsgQuoteListener : public nsIMimeStreamConverterListener {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGQUOTELISTENER_IID)

  /* attribute nsIMsgQuote msgQuote; */
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote) = 0;
  NS_IMETHOD SetMsgQuote(nsIMsgQuote * aMsgQuote) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGQUOTELISTENER \
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote); \
  NS_IMETHOD SetMsgQuote(nsIMsgQuote * aMsgQuote); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGQUOTELISTENER(_to) \
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote) { return _to GetMsgQuote(aMsgQuote); } \
  NS_IMETHOD SetMsgQuote(nsIMsgQuote * aMsgQuote) { return _to SetMsgQuote(aMsgQuote); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGQUOTELISTENER(_to) \
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgQuote(aMsgQuote); } \
  NS_IMETHOD SetMsgQuote(nsIMsgQuote * aMsgQuote) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgQuote(aMsgQuote); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgQuoteListener : public nsIMsgQuoteListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGQUOTELISTENER

  nsMsgQuoteListener();

private:
  ~nsMsgQuoteListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgQuoteListener, nsIMsgQuoteListener)

nsMsgQuoteListener::nsMsgQuoteListener()
{
  /* member initializers and constructor code */
}

nsMsgQuoteListener::~nsMsgQuoteListener()
{
  /* destructor code */
}

/* attribute nsIMsgQuote msgQuote; */
NS_IMETHODIMP nsMsgQuoteListener::GetMsgQuote(nsIMsgQuote * *aMsgQuote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgQuoteListener::SetMsgQuote(nsIMsgQuote * aMsgQuote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgQuote_h__ */
