/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImapFlagAndUidState.idl
 */

#ifndef __gen_nsIImapFlagAndUidState_h__
#define __gen_nsIImapFlagAndUidState_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIImapFlagAndUidState */
#define NS_IIMAPFLAGANDUIDSTATE_IID_STR "d4ba3414-fe9e-436b-a01b-bd446e737d04"

#define NS_IIMAPFLAGANDUIDSTATE_IID \
  {0xd4ba3414, 0xfe9e, 0x436b, \
    { 0xa0, 0x1b, 0xbd, 0x44, 0x6e, 0x73, 0x7d, 0x04 }}

class NS_NO_VTABLE nsIImapFlagAndUidState : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMAPFLAGANDUIDSTATE_IID)

  /* readonly attribute long numberOfMessages; */
  NS_IMETHOD GetNumberOfMessages(PRInt32 *aNumberOfMessages) = 0;

  /* readonly attribute long numberOfRecentMessages; */
  NS_IMETHOD GetNumberOfRecentMessages(PRInt32 *aNumberOfRecentMessages) = 0;

  /* void getUidOfMessage (in long zeroBasedIndex, out unsigned long result); */
  NS_IMETHOD GetUidOfMessage(PRInt32 zeroBasedIndex, PRUint32 *result) = 0;

  /* void getMessageFlags (in long zeroBasedIndex, out unsigned short result); */
  NS_IMETHOD GetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 *result) = 0;

  /* void setMessageFlags (in long zeroBasedIndex, in unsigned short flags); */
  NS_IMETHOD SetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 flags) = 0;

  /* void expungeByIndex (in unsigned long zeroBasedIndex); */
  NS_IMETHOD ExpungeByIndex(PRUint32 zeroBasedIndex) = 0;

  /* void addUidFlagPair (in unsigned long uid, in unsigned short flags, in unsigned long zeroBasedIndex); */
  NS_IMETHOD AddUidFlagPair(PRUint32 uid, PRUint16 flags, PRUint32 zeroBasedIndex) = 0;

  /* void addUidCustomFlagPair (in unsigned long uid, in string customFlag); */
  NS_IMETHOD AddUidCustomFlagPair(PRUint32 uid, const char *customFlag) = 0;

  /* string getCustomFlags (in unsigned long uid); */
  NS_IMETHOD GetCustomFlags(PRUint32 uid, char **_retval) = 0;

  /* void reset (in unsigned long howManyLeft); */
  NS_IMETHOD Reset(PRUint32 howManyLeft) = 0;

  /* void setSupportedUserFlags (in unsigned short flags); */
  NS_IMETHOD SetSupportedUserFlags(PRUint16 flags) = 0;

  /* void clearCustomFlags (in unsigned long uid); */
  NS_IMETHOD ClearCustomFlags(PRUint32 uid) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPFLAGANDUIDSTATE \
  NS_IMETHOD GetNumberOfMessages(PRInt32 *aNumberOfMessages); \
  NS_IMETHOD GetNumberOfRecentMessages(PRInt32 *aNumberOfRecentMessages); \
  NS_IMETHOD GetUidOfMessage(PRInt32 zeroBasedIndex, PRUint32 *result); \
  NS_IMETHOD GetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 *result); \
  NS_IMETHOD SetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 flags); \
  NS_IMETHOD ExpungeByIndex(PRUint32 zeroBasedIndex); \
  NS_IMETHOD AddUidFlagPair(PRUint32 uid, PRUint16 flags, PRUint32 zeroBasedIndex); \
  NS_IMETHOD AddUidCustomFlagPair(PRUint32 uid, const char *customFlag); \
  NS_IMETHOD GetCustomFlags(PRUint32 uid, char **_retval); \
  NS_IMETHOD Reset(PRUint32 howManyLeft); \
  NS_IMETHOD SetSupportedUserFlags(PRUint16 flags); \
  NS_IMETHOD ClearCustomFlags(PRUint32 uid); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPFLAGANDUIDSTATE(_to) \
  NS_IMETHOD GetNumberOfMessages(PRInt32 *aNumberOfMessages) { return _to GetNumberOfMessages(aNumberOfMessages); } \
  NS_IMETHOD GetNumberOfRecentMessages(PRInt32 *aNumberOfRecentMessages) { return _to GetNumberOfRecentMessages(aNumberOfRecentMessages); } \
  NS_IMETHOD GetUidOfMessage(PRInt32 zeroBasedIndex, PRUint32 *result) { return _to GetUidOfMessage(zeroBasedIndex, result); } \
  NS_IMETHOD GetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 *result) { return _to GetMessageFlags(zeroBasedIndex, result); } \
  NS_IMETHOD SetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 flags) { return _to SetMessageFlags(zeroBasedIndex, flags); } \
  NS_IMETHOD ExpungeByIndex(PRUint32 zeroBasedIndex) { return _to ExpungeByIndex(zeroBasedIndex); } \
  NS_IMETHOD AddUidFlagPair(PRUint32 uid, PRUint16 flags, PRUint32 zeroBasedIndex) { return _to AddUidFlagPair(uid, flags, zeroBasedIndex); } \
  NS_IMETHOD AddUidCustomFlagPair(PRUint32 uid, const char *customFlag) { return _to AddUidCustomFlagPair(uid, customFlag); } \
  NS_IMETHOD GetCustomFlags(PRUint32 uid, char **_retval) { return _to GetCustomFlags(uid, _retval); } \
  NS_IMETHOD Reset(PRUint32 howManyLeft) { return _to Reset(howManyLeft); } \
  NS_IMETHOD SetSupportedUserFlags(PRUint16 flags) { return _to SetSupportedUserFlags(flags); } \
  NS_IMETHOD ClearCustomFlags(PRUint32 uid) { return _to ClearCustomFlags(uid); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPFLAGANDUIDSTATE(_to) \
  NS_IMETHOD GetNumberOfMessages(PRInt32 *aNumberOfMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumberOfMessages(aNumberOfMessages); } \
  NS_IMETHOD GetNumberOfRecentMessages(PRInt32 *aNumberOfRecentMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumberOfRecentMessages(aNumberOfRecentMessages); } \
  NS_IMETHOD GetUidOfMessage(PRInt32 zeroBasedIndex, PRUint32 *result) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUidOfMessage(zeroBasedIndex, result); } \
  NS_IMETHOD GetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 *result) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageFlags(zeroBasedIndex, result); } \
  NS_IMETHOD SetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessageFlags(zeroBasedIndex, flags); } \
  NS_IMETHOD ExpungeByIndex(PRUint32 zeroBasedIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->ExpungeByIndex(zeroBasedIndex); } \
  NS_IMETHOD AddUidFlagPair(PRUint32 uid, PRUint16 flags, PRUint32 zeroBasedIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddUidFlagPair(uid, flags, zeroBasedIndex); } \
  NS_IMETHOD AddUidCustomFlagPair(PRUint32 uid, const char *customFlag) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddUidCustomFlagPair(uid, customFlag); } \
  NS_IMETHOD GetCustomFlags(PRUint32 uid, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCustomFlags(uid, _retval); } \
  NS_IMETHOD Reset(PRUint32 howManyLeft) { return !_to ? NS_ERROR_NULL_POINTER : _to->Reset(howManyLeft); } \
  NS_IMETHOD SetSupportedUserFlags(PRUint16 flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSupportedUserFlags(flags); } \
  NS_IMETHOD ClearCustomFlags(PRUint32 uid) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearCustomFlags(uid); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapFlagAndUidState : public nsIImapFlagAndUidState
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPFLAGANDUIDSTATE

  nsImapFlagAndUidState();

private:
  ~nsImapFlagAndUidState();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapFlagAndUidState, nsIImapFlagAndUidState)

nsImapFlagAndUidState::nsImapFlagAndUidState()
{
  /* member initializers and constructor code */
}

nsImapFlagAndUidState::~nsImapFlagAndUidState()
{
  /* destructor code */
}

/* readonly attribute long numberOfMessages; */
NS_IMETHODIMP nsImapFlagAndUidState::GetNumberOfMessages(PRInt32 *aNumberOfMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numberOfRecentMessages; */
NS_IMETHODIMP nsImapFlagAndUidState::GetNumberOfRecentMessages(PRInt32 *aNumberOfRecentMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getUidOfMessage (in long zeroBasedIndex, out unsigned long result); */
NS_IMETHODIMP nsImapFlagAndUidState::GetUidOfMessage(PRInt32 zeroBasedIndex, PRUint32 *result)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getMessageFlags (in long zeroBasedIndex, out unsigned short result); */
NS_IMETHODIMP nsImapFlagAndUidState::GetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 *result)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMessageFlags (in long zeroBasedIndex, in unsigned short flags); */
NS_IMETHODIMP nsImapFlagAndUidState::SetMessageFlags(PRInt32 zeroBasedIndex, PRUint16 flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void expungeByIndex (in unsigned long zeroBasedIndex); */
NS_IMETHODIMP nsImapFlagAndUidState::ExpungeByIndex(PRUint32 zeroBasedIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addUidFlagPair (in unsigned long uid, in unsigned short flags, in unsigned long zeroBasedIndex); */
NS_IMETHODIMP nsImapFlagAndUidState::AddUidFlagPair(PRUint32 uid, PRUint16 flags, PRUint32 zeroBasedIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addUidCustomFlagPair (in unsigned long uid, in string customFlag); */
NS_IMETHODIMP nsImapFlagAndUidState::AddUidCustomFlagPair(PRUint32 uid, const char *customFlag)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string getCustomFlags (in unsigned long uid); */
NS_IMETHODIMP nsImapFlagAndUidState::GetCustomFlags(PRUint32 uid, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void reset (in unsigned long howManyLeft); */
NS_IMETHODIMP nsImapFlagAndUidState::Reset(PRUint32 howManyLeft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setSupportedUserFlags (in unsigned short flags); */
NS_IMETHODIMP nsImapFlagAndUidState::SetSupportedUserFlags(PRUint16 flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearCustomFlags (in unsigned long uid); */
NS_IMETHODIMP nsImapFlagAndUidState::ClearCustomFlags(PRUint32 uid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapFlagAndUidState_h__ */
