/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportSettings.idl
 */

#ifndef __gen_nsIImportSettings_h__
#define __gen_nsIImportSettings_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgAccount; /* forward declaration */

class nsIFileSpec; /* forward declaration */


/* starting interface:    nsIImportSettings */
#define NS_IIMPORTSETTINGS_IID_STR "a9411860-66ac-11d3-a206-00a0cc26da63"

#define NS_IIMPORTSETTINGS_IID \
  {0xa9411860, 0x66ac, 0x11d3, \
    { 0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63 }}

class NS_NO_VTABLE nsIImportSettings : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMPORTSETTINGS_IID)

  /* boolean AutoLocate (out wstring description, out nsIFileSpec location); */
  NS_IMETHOD AutoLocate(PRUnichar **description, nsIFileSpec **location, PRBool *_retval) = 0;

  /* void SetLocation (in nsIFileSpec location); */
  NS_IMETHOD SetLocation(nsIFileSpec *location) = 0;

  /* boolean Import (out nsIMsgAccount localMailAccount); */
  NS_IMETHOD Import(nsIMsgAccount **localMailAccount, PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTSETTINGS \
  NS_IMETHOD AutoLocate(PRUnichar **description, nsIFileSpec **location, PRBool *_retval); \
  NS_IMETHOD SetLocation(nsIFileSpec *location); \
  NS_IMETHOD Import(nsIMsgAccount **localMailAccount, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTSETTINGS(_to) \
  NS_IMETHOD AutoLocate(PRUnichar **description, nsIFileSpec **location, PRBool *_retval) { return _to AutoLocate(description, location, _retval); } \
  NS_IMETHOD SetLocation(nsIFileSpec *location) { return _to SetLocation(location); } \
  NS_IMETHOD Import(nsIMsgAccount **localMailAccount, PRBool *_retval) { return _to Import(localMailAccount, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTSETTINGS(_to) \
  NS_IMETHOD AutoLocate(PRUnichar **description, nsIFileSpec **location, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AutoLocate(description, location, _retval); } \
  NS_IMETHOD SetLocation(nsIFileSpec *location) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLocation(location); } \
  NS_IMETHOD Import(nsIMsgAccount **localMailAccount, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Import(localMailAccount, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportSettings : public nsIImportSettings
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTSETTINGS

  nsImportSettings();

private:
  ~nsImportSettings();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportSettings, nsIImportSettings)

nsImportSettings::nsImportSettings()
{
  /* member initializers and constructor code */
}

nsImportSettings::~nsImportSettings()
{
  /* destructor code */
}

/* boolean AutoLocate (out wstring description, out nsIFileSpec location); */
NS_IMETHODIMP nsImportSettings::AutoLocate(PRUnichar **description, nsIFileSpec **location, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetLocation (in nsIFileSpec location); */
NS_IMETHODIMP nsImportSettings::SetLocation(nsIFileSpec *location)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean Import (out nsIMsgAccount localMailAccount); */
NS_IMETHODIMP nsImportSettings::Import(nsIMsgAccount **localMailAccount, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImportSettings_h__ */
