/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgFilterService.idl
 */

#ifndef __gen_nsIMsgFilterService_h__
#define __gen_nsIMsgFilterService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgFilterList_h__
#include "nsIMsgFilterList.h"
#endif

#ifndef __gen_nsIMsgWindow_h__
#include "nsIMsgWindow.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgFilterService */
#define NS_IMSGFILTERSERVICE_IID_STR "6673cad0-072e-11d3-8d70-00805f8a6617"

#define NS_IMSGFILTERSERVICE_IID \
  {0x6673cad0, 0x072e, 0x11d3, \
    { 0x8d, 0x70, 0x00, 0x80, 0x5f, 0x8a, 0x66, 0x17 }}

class NS_NO_VTABLE nsIMsgFilterService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGFILTERSERVICE_IID)

  /* nsIMsgFilterList OpenFilterList (in nsIFileSpec filterFile, in nsIMsgFolder rootFolder, in nsIMsgWindow msgWindow); */
  NS_IMETHOD OpenFilterList(nsIFileSpec *filterFile, nsIMsgFolder *rootFolder, nsIMsgWindow *msgWindow, nsIMsgFilterList **_retval) = 0;

  /* void CloseFilterList (in nsIMsgFilterList filterList); */
  NS_IMETHOD CloseFilterList(nsIMsgFilterList *filterList) = 0;

  /* void SaveFilterList (in nsIMsgFilterList filterList, in nsIFileSpec filterFile); */
  NS_IMETHOD SaveFilterList(nsIMsgFilterList *filterList, nsIFileSpec *filterFile) = 0;

  /* void CancelFilterList (in nsIMsgFilterList filterList); */
  NS_IMETHOD CancelFilterList(nsIMsgFilterList *filterList) = 0;

  /* nsIMsgFilterList getTempFilterList (in nsIMsgFolder aFolder); */
  NS_IMETHOD GetTempFilterList(nsIMsgFolder *aFolder, nsIMsgFilterList **_retval) = 0;

  /* void applyFiltersToFolders (in nsIMsgFilterList aFilterList, in nsISupportsArray aFolders, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsISupportsArray *aFolders, nsIMsgWindow *aMsgWindow) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFILTERSERVICE \
  NS_IMETHOD OpenFilterList(nsIFileSpec *filterFile, nsIMsgFolder *rootFolder, nsIMsgWindow *msgWindow, nsIMsgFilterList **_retval); \
  NS_IMETHOD CloseFilterList(nsIMsgFilterList *filterList); \
  NS_IMETHOD SaveFilterList(nsIMsgFilterList *filterList, nsIFileSpec *filterFile); \
  NS_IMETHOD CancelFilterList(nsIMsgFilterList *filterList); \
  NS_IMETHOD GetTempFilterList(nsIMsgFolder *aFolder, nsIMsgFilterList **_retval); \
  NS_IMETHOD ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsISupportsArray *aFolders, nsIMsgWindow *aMsgWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFILTERSERVICE(_to) \
  NS_IMETHOD OpenFilterList(nsIFileSpec *filterFile, nsIMsgFolder *rootFolder, nsIMsgWindow *msgWindow, nsIMsgFilterList **_retval) { return _to OpenFilterList(filterFile, rootFolder, msgWindow, _retval); } \
  NS_IMETHOD CloseFilterList(nsIMsgFilterList *filterList) { return _to CloseFilterList(filterList); } \
  NS_IMETHOD SaveFilterList(nsIMsgFilterList *filterList, nsIFileSpec *filterFile) { return _to SaveFilterList(filterList, filterFile); } \
  NS_IMETHOD CancelFilterList(nsIMsgFilterList *filterList) { return _to CancelFilterList(filterList); } \
  NS_IMETHOD GetTempFilterList(nsIMsgFolder *aFolder, nsIMsgFilterList **_retval) { return _to GetTempFilterList(aFolder, _retval); } \
  NS_IMETHOD ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsISupportsArray *aFolders, nsIMsgWindow *aMsgWindow) { return _to ApplyFiltersToFolders(aFilterList, aFolders, aMsgWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFILTERSERVICE(_to) \
  NS_IMETHOD OpenFilterList(nsIFileSpec *filterFile, nsIMsgFolder *rootFolder, nsIMsgWindow *msgWindow, nsIMsgFilterList **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenFilterList(filterFile, rootFolder, msgWindow, _retval); } \
  NS_IMETHOD CloseFilterList(nsIMsgFilterList *filterList) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloseFilterList(filterList); } \
  NS_IMETHOD SaveFilterList(nsIMsgFilterList *filterList, nsIFileSpec *filterFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->SaveFilterList(filterList, filterFile); } \
  NS_IMETHOD CancelFilterList(nsIMsgFilterList *filterList) { return !_to ? NS_ERROR_NULL_POINTER : _to->CancelFilterList(filterList); } \
  NS_IMETHOD GetTempFilterList(nsIMsgFolder *aFolder, nsIMsgFilterList **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTempFilterList(aFolder, _retval); } \
  NS_IMETHOD ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsISupportsArray *aFolders, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->ApplyFiltersToFolders(aFilterList, aFolders, aMsgWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFilterService : public nsIMsgFilterService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFILTERSERVICE

  nsMsgFilterService();

private:
  ~nsMsgFilterService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFilterService, nsIMsgFilterService)

nsMsgFilterService::nsMsgFilterService()
{
  /* member initializers and constructor code */
}

nsMsgFilterService::~nsMsgFilterService()
{
  /* destructor code */
}

/* nsIMsgFilterList OpenFilterList (in nsIFileSpec filterFile, in nsIMsgFolder rootFolder, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgFilterService::OpenFilterList(nsIFileSpec *filterFile, nsIMsgFolder *rootFolder, nsIMsgWindow *msgWindow, nsIMsgFilterList **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CloseFilterList (in nsIMsgFilterList filterList); */
NS_IMETHODIMP nsMsgFilterService::CloseFilterList(nsIMsgFilterList *filterList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SaveFilterList (in nsIMsgFilterList filterList, in nsIFileSpec filterFile); */
NS_IMETHODIMP nsMsgFilterService::SaveFilterList(nsIMsgFilterList *filterList, nsIFileSpec *filterFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CancelFilterList (in nsIMsgFilterList filterList); */
NS_IMETHODIMP nsMsgFilterService::CancelFilterList(nsIMsgFilterList *filterList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgFilterList getTempFilterList (in nsIMsgFolder aFolder); */
NS_IMETHODIMP nsMsgFilterService::GetTempFilterList(nsIMsgFolder *aFolder, nsIMsgFilterList **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void applyFiltersToFolders (in nsIMsgFilterList aFilterList, in nsISupportsArray aFolders, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgFilterService::ApplyFiltersToFolders(nsIMsgFilterList *aFilterList, nsISupportsArray *aFolders, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFilterService_h__ */
