/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMovemailService.idl
 */

#ifndef __gen_nsIMovemailService_h__
#define __gen_nsIMovemailService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListener_h__
#include "nsIUrlListener.h"
#endif

#ifndef __gen_nsIMovemailIncomingServer_h__
#include "nsIMovemailIncomingServer.h"
#endif

#ifndef __gen_nsIMsgFolder_h__
#include "nsIMsgFolder.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMovemailService */
#define NS_IMOVEMAILSERVICE_IID_STR "4c7786a4-1dd2-11b2-9fbe-c59d742de59b"

#define NS_IMOVEMAILSERVICE_IID \
  {0x4c7786a4, 0x1dd2, 0x11b2, \
    { 0x9f, 0xbe, 0xc5, 0x9d, 0x74, 0x2d, 0xe5, 0x9b }}

class NS_NO_VTABLE nsIMovemailService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMOVEMAILSERVICE_IID)

  /* nsIURI GetNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aMsgFolder, in nsIMovemailIncomingServer movemailServer); */
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aMsgFolder, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval) = 0;

  /* nsIURI CheckForNewMail (in nsIUrlListener aUrlListener, in nsIMsgFolder inbox, in nsIMovemailIncomingServer movemailServer); */
  NS_IMETHOD CheckForNewMail(nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMOVEMAILSERVICE \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aMsgFolder, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval); \
  NS_IMETHOD CheckForNewMail(nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMOVEMAILSERVICE(_to) \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aMsgFolder, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval) { return _to GetNewMail(aMsgWindow, aUrlListener, aMsgFolder, movemailServer, _retval); } \
  NS_IMETHOD CheckForNewMail(nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval) { return _to CheckForNewMail(aUrlListener, inbox, movemailServer, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMOVEMAILSERVICE(_to) \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aMsgFolder, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewMail(aMsgWindow, aUrlListener, aMsgFolder, movemailServer, _retval); } \
  NS_IMETHOD CheckForNewMail(nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckForNewMail(aUrlListener, inbox, movemailServer, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMovemailService : public nsIMovemailService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMOVEMAILSERVICE

  nsMovemailService();

private:
  ~nsMovemailService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMovemailService, nsIMovemailService)

nsMovemailService::nsMovemailService()
{
  /* member initializers and constructor code */
}

nsMovemailService::~nsMovemailService()
{
  /* destructor code */
}

/* nsIURI GetNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aMsgFolder, in nsIMovemailIncomingServer movemailServer); */
NS_IMETHODIMP nsMovemailService::GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aMsgFolder, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI CheckForNewMail (in nsIUrlListener aUrlListener, in nsIMsgFolder inbox, in nsIMovemailIncomingServer movemailServer); */
NS_IMETHODIMP nsMovemailService::CheckForNewMail(nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIMovemailIncomingServer *movemailServer, nsIURI **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMovemailService_h__ */
