/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIUrlListener.idl"
#include "nsIPop3IncomingServer.idl"
#include "nsIMsgFolder.idl"

interface nsIURI;
interface nsIStreamListener;
interface nsIMsgWindow;
interface nsIMsgFolder;
/*
 * The Pop3 Service is an interface designed to make building and running
 * pop3 urls easier. I'm not sure if this service will go away when the
 * new networking model comes on line (as part of the N2 project). So
 * I reserve the right to change my mind and take this service away =).
 */
[scriptable, uuid(3BB459E0-D746-11d2-806A-006008128C4E)]
interface nsIPop3Service : nsISupports {
  /*
   * All of these functions build pop3 urls and run them. If you want
   * a handle on the running task, pass in a valid nsIURI ptr. You can later
   * interrupt this action by asking the netlib service manager to interrupt
   * the url you are given back. Remember to release aURL when you are
   * done with it. Pass nsnull in for aURL if you
   * don't care about the returned URL.
   */

  /*
   * right now getting new mail doesn't require any user specific data.
   * We use the default current identity for this information. I suspect that
   * we'll eventually pass in an identity to this call so you can get
   * mail on different pop3 accounts....
   */
  
  nsIURI GetNewMail(in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener,
					in nsIMsgFolder aInbox,
                    in nsIPop3IncomingServer popServer);

  nsIURI CheckForNewMail(in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener,
						 in nsIMsgFolder inbox,
                         in nsIPop3IncomingServer popServer);
};
