/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSearchSession.idl
 */

#ifndef __gen_nsIMsgSearchSession_h__
#define __gen_nsIMsgSearchSession_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsMsgSearchCore_h__
#include "nsMsgSearchCore.h"
#endif

#ifndef __gen_nsIMsgSearchValue_h__
#include "nsIMsgSearchValue.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsMsgResultElement; /* forward declaration */

class nsIMsgSearchAdapter; /* forward declaration */

class nsIMsgSearchTerm; /* forward declaration */

class nsIMsgSearchNotify; /* forward declaration */

class nsIMsgHdr; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */


/* starting interface:    nsIMsgSearchSession */
#define NS_IMSGSEARCHSESSION_IID_STR "a819050a-0302-11d3-a50a-0060b0fc04b7"

#define NS_IMSGSEARCHSESSION_IID \
  {0xa819050a, 0x0302, 0x11d3, \
    { 0xa5, 0x0a, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xb7 }}

class NS_NO_VTABLE nsIMsgSearchSession : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHSESSION_IID)

  /* void addSearchTerm (in nsMsgSearchAttribValue attrib, in nsMsgSearchOpValue op, in nsIMsgSearchValue value, in boolean BooleanAND, in string arbitraryHeader); */
  NS_IMETHOD AddSearchTerm(nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value, PRBool BooleanAND, const char *arbitraryHeader) = 0;

  /* readonly attribute nsISupportsArray searchTerms; */
  NS_IMETHOD GetSearchTerms(nsISupportsArray * *aSearchTerms) = 0;

  /* nsIMsgSearchTerm createTerm (); */
  NS_IMETHOD CreateTerm(nsIMsgSearchTerm **_retval) = 0;

  /* void appendTerm (in nsIMsgSearchTerm term); */
  NS_IMETHOD AppendTerm(nsIMsgSearchTerm *term) = 0;

  /* void registerListener (in nsIMsgSearchNotify listener); */
  NS_IMETHOD RegisterListener(nsIMsgSearchNotify *listener) = 0;

  /* void unregisterListener (in nsIMsgSearchNotify listener); */
  NS_IMETHOD UnregisterListener(nsIMsgSearchNotify *listener) = 0;

  /* readonly attribute unsigned long numSearchTerms; */
  NS_IMETHOD GetNumSearchTerms(PRUint32 *aNumSearchTerms) = 0;

  /* readonly attribute nsIMsgSearchAdapter runningAdapter; */
  NS_IMETHOD GetRunningAdapter(nsIMsgSearchAdapter * *aRunningAdapter) = 0;

  /* void getNthSearchTerm (in long whichTerm, in nsMsgSearchAttribValue attrib, in nsMsgSearchOpValue op, in nsIMsgSearchValue value); */
  NS_IMETHOD GetNthSearchTerm(PRInt32 whichTerm, nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value) = 0;

  /* long countSearchScopes (); */
  NS_IMETHOD CountSearchScopes(PRInt32 *_retval) = 0;

  /* void getNthSearchScope (in long which, out nsMsgSearchScopeValue scopeId, out nsIMsgFolder folder); */
  NS_IMETHOD GetNthSearchScope(PRInt32 which, nsMsgSearchScopeValue *scopeId, nsIMsgFolder **folder) = 0;

  /* void addScopeTerm (in nsMsgSearchScopeValue scope, in nsIMsgFolder folder); */
  NS_IMETHOD AddScopeTerm(nsMsgSearchScopeValue scope, nsIMsgFolder *folder) = 0;

  /* void addDirectoryScopeTerm (in nsMsgSearchScopeValue scope); */
  NS_IMETHOD AddDirectoryScopeTerm(nsMsgSearchScopeValue scope) = 0;

  /* void clearScopes (); */
  NS_IMETHOD ClearScopes(void) = 0;

  /* [noscript] boolean ScopeUsesCustomHeaders (in nsMsgSearchScopeValue scope, in voidPtr selection, in boolean forFilters); */
  NS_IMETHOD ScopeUsesCustomHeaders(nsMsgSearchScopeValue scope, void * selection, PRBool forFilters, PRBool *_retval) = 0;

  /* boolean IsStringAttribute (in nsMsgSearchAttribValue attrib); */
  NS_IMETHOD IsStringAttribute(nsMsgSearchAttribValue attrib, PRBool *_retval) = 0;

  /* void AddAllScopes (in nsMsgSearchScopeValue attrib); */
  NS_IMETHOD AddAllScopes(nsMsgSearchScopeValue attrib) = 0;

  /* void search (in nsIMsgWindow aWindow); */
  NS_IMETHOD Search(nsIMsgWindow *aWindow) = 0;

  /* void interruptSearch (); */
  NS_IMETHOD InterruptSearch(void) = 0;

  /* void pauseSearch (); */
  NS_IMETHOD PauseSearch(void) = 0;

  /* void resumeSearch (); */
  NS_IMETHOD ResumeSearch(void) = 0;

  /* [noscript] readonly attribute voidPtr searchParam; */
  NS_IMETHOD GetSearchParam(void * *aSearchParam) = 0;

  /* readonly attribute nsMsgSearchType searchType; */
  NS_IMETHOD GetSearchType(nsMsgSearchType * *aSearchType) = 0;

  /* [noscript] nsMsgSearchType SetSearchParam (in nsMsgSearchType type, in voidPtr param); */
  NS_IMETHOD SetSearchParam(nsMsgSearchType *type, void * param, nsMsgSearchType **_retval) = 0;

  /* [noscript] void AddResultElement (in nsMsgResultElement element); */
  NS_IMETHOD AddResultElement(nsMsgResultElement *element) = 0;

  /* boolean MatchHdr (in nsIMsgDBHdr aMsgHdr, in nsIMsgDatabase aDatabase); */
  NS_IMETHOD MatchHdr(nsIMsgDBHdr *aMsgHdr, nsIMsgDatabase *aDatabase, PRBool *_retval) = 0;

  /* void addSearchHit (in nsIMsgDBHdr header, in nsIMsgFolder folder); */
  NS_IMETHOD AddSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder) = 0;

  /* readonly attribute long numResults; */
  NS_IMETHOD GetNumResults(PRInt32 *aNumResults) = 0;

  /* attribute nsIMsgWindow window; */
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) = 0;
  NS_IMETHOD SetWindow(nsIMsgWindow * aWindow) = 0;

  enum { BooleanOR = 0 };

  enum { BooleanAND = 1 };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHSESSION \
  NS_IMETHOD AddSearchTerm(nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value, PRBool BooleanAND, const char *arbitraryHeader); \
  NS_IMETHOD GetSearchTerms(nsISupportsArray * *aSearchTerms); \
  NS_IMETHOD CreateTerm(nsIMsgSearchTerm **_retval); \
  NS_IMETHOD AppendTerm(nsIMsgSearchTerm *term); \
  NS_IMETHOD RegisterListener(nsIMsgSearchNotify *listener); \
  NS_IMETHOD UnregisterListener(nsIMsgSearchNotify *listener); \
  NS_IMETHOD GetNumSearchTerms(PRUint32 *aNumSearchTerms); \
  NS_IMETHOD GetRunningAdapter(nsIMsgSearchAdapter * *aRunningAdapter); \
  NS_IMETHOD GetNthSearchTerm(PRInt32 whichTerm, nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value); \
  NS_IMETHOD CountSearchScopes(PRInt32 *_retval); \
  NS_IMETHOD GetNthSearchScope(PRInt32 which, nsMsgSearchScopeValue *scopeId, nsIMsgFolder **folder); \
  NS_IMETHOD AddScopeTerm(nsMsgSearchScopeValue scope, nsIMsgFolder *folder); \
  NS_IMETHOD AddDirectoryScopeTerm(nsMsgSearchScopeValue scope); \
  NS_IMETHOD ClearScopes(void); \
  NS_IMETHOD ScopeUsesCustomHeaders(nsMsgSearchScopeValue scope, void * selection, PRBool forFilters, PRBool *_retval); \
  NS_IMETHOD IsStringAttribute(nsMsgSearchAttribValue attrib, PRBool *_retval); \
  NS_IMETHOD AddAllScopes(nsMsgSearchScopeValue attrib); \
  NS_IMETHOD Search(nsIMsgWindow *aWindow); \
  NS_IMETHOD InterruptSearch(void); \
  NS_IMETHOD PauseSearch(void); \
  NS_IMETHOD ResumeSearch(void); \
  NS_IMETHOD GetSearchParam(void * *aSearchParam); \
  NS_IMETHOD GetSearchType(nsMsgSearchType * *aSearchType); \
  NS_IMETHOD SetSearchParam(nsMsgSearchType *type, void * param, nsMsgSearchType **_retval); \
  NS_IMETHOD AddResultElement(nsMsgResultElement *element); \
  NS_IMETHOD MatchHdr(nsIMsgDBHdr *aMsgHdr, nsIMsgDatabase *aDatabase, PRBool *_retval); \
  NS_IMETHOD AddSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder); \
  NS_IMETHOD GetNumResults(PRInt32 *aNumResults); \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow); \
  NS_IMETHOD SetWindow(nsIMsgWindow * aWindow); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHSESSION(_to) \
  NS_IMETHOD AddSearchTerm(nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value, PRBool BooleanAND, const char *arbitraryHeader) { return _to AddSearchTerm(attrib, op, value, BooleanAND, arbitraryHeader); } \
  NS_IMETHOD GetSearchTerms(nsISupportsArray * *aSearchTerms) { return _to GetSearchTerms(aSearchTerms); } \
  NS_IMETHOD CreateTerm(nsIMsgSearchTerm **_retval) { return _to CreateTerm(_retval); } \
  NS_IMETHOD AppendTerm(nsIMsgSearchTerm *term) { return _to AppendTerm(term); } \
  NS_IMETHOD RegisterListener(nsIMsgSearchNotify *listener) { return _to RegisterListener(listener); } \
  NS_IMETHOD UnregisterListener(nsIMsgSearchNotify *listener) { return _to UnregisterListener(listener); } \
  NS_IMETHOD GetNumSearchTerms(PRUint32 *aNumSearchTerms) { return _to GetNumSearchTerms(aNumSearchTerms); } \
  NS_IMETHOD GetRunningAdapter(nsIMsgSearchAdapter * *aRunningAdapter) { return _to GetRunningAdapter(aRunningAdapter); } \
  NS_IMETHOD GetNthSearchTerm(PRInt32 whichTerm, nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value) { return _to GetNthSearchTerm(whichTerm, attrib, op, value); } \
  NS_IMETHOD CountSearchScopes(PRInt32 *_retval) { return _to CountSearchScopes(_retval); } \
  NS_IMETHOD GetNthSearchScope(PRInt32 which, nsMsgSearchScopeValue *scopeId, nsIMsgFolder **folder) { return _to GetNthSearchScope(which, scopeId, folder); } \
  NS_IMETHOD AddScopeTerm(nsMsgSearchScopeValue scope, nsIMsgFolder *folder) { return _to AddScopeTerm(scope, folder); } \
  NS_IMETHOD AddDirectoryScopeTerm(nsMsgSearchScopeValue scope) { return _to AddDirectoryScopeTerm(scope); } \
  NS_IMETHOD ClearScopes(void) { return _to ClearScopes(); } \
  NS_IMETHOD ScopeUsesCustomHeaders(nsMsgSearchScopeValue scope, void * selection, PRBool forFilters, PRBool *_retval) { return _to ScopeUsesCustomHeaders(scope, selection, forFilters, _retval); } \
  NS_IMETHOD IsStringAttribute(nsMsgSearchAttribValue attrib, PRBool *_retval) { return _to IsStringAttribute(attrib, _retval); } \
  NS_IMETHOD AddAllScopes(nsMsgSearchScopeValue attrib) { return _to AddAllScopes(attrib); } \
  NS_IMETHOD Search(nsIMsgWindow *aWindow) { return _to Search(aWindow); } \
  NS_IMETHOD InterruptSearch(void) { return _to InterruptSearch(); } \
  NS_IMETHOD PauseSearch(void) { return _to PauseSearch(); } \
  NS_IMETHOD ResumeSearch(void) { return _to ResumeSearch(); } \
  NS_IMETHOD GetSearchParam(void * *aSearchParam) { return _to GetSearchParam(aSearchParam); } \
  NS_IMETHOD GetSearchType(nsMsgSearchType * *aSearchType) { return _to GetSearchType(aSearchType); } \
  NS_IMETHOD SetSearchParam(nsMsgSearchType *type, void * param, nsMsgSearchType **_retval) { return _to SetSearchParam(type, param, _retval); } \
  NS_IMETHOD AddResultElement(nsMsgResultElement *element) { return _to AddResultElement(element); } \
  NS_IMETHOD MatchHdr(nsIMsgDBHdr *aMsgHdr, nsIMsgDatabase *aDatabase, PRBool *_retval) { return _to MatchHdr(aMsgHdr, aDatabase, _retval); } \
  NS_IMETHOD AddSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder) { return _to AddSearchHit(header, folder); } \
  NS_IMETHOD GetNumResults(PRInt32 *aNumResults) { return _to GetNumResults(aNumResults); } \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) { return _to GetWindow(aWindow); } \
  NS_IMETHOD SetWindow(nsIMsgWindow * aWindow) { return _to SetWindow(aWindow); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHSESSION(_to) \
  NS_IMETHOD AddSearchTerm(nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value, PRBool BooleanAND, const char *arbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddSearchTerm(attrib, op, value, BooleanAND, arbitraryHeader); } \
  NS_IMETHOD GetSearchTerms(nsISupportsArray * *aSearchTerms) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchTerms(aSearchTerms); } \
  NS_IMETHOD CreateTerm(nsIMsgSearchTerm **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateTerm(_retval); } \
  NS_IMETHOD AppendTerm(nsIMsgSearchTerm *term) { return !_to ? NS_ERROR_NULL_POINTER : _to->AppendTerm(term); } \
  NS_IMETHOD RegisterListener(nsIMsgSearchNotify *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterListener(listener); } \
  NS_IMETHOD UnregisterListener(nsIMsgSearchNotify *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->UnregisterListener(listener); } \
  NS_IMETHOD GetNumSearchTerms(PRUint32 *aNumSearchTerms) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumSearchTerms(aNumSearchTerms); } \
  NS_IMETHOD GetRunningAdapter(nsIMsgSearchAdapter * *aRunningAdapter) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRunningAdapter(aRunningAdapter); } \
  NS_IMETHOD GetNthSearchTerm(PRInt32 whichTerm, nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNthSearchTerm(whichTerm, attrib, op, value); } \
  NS_IMETHOD CountSearchScopes(PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CountSearchScopes(_retval); } \
  NS_IMETHOD GetNthSearchScope(PRInt32 which, nsMsgSearchScopeValue *scopeId, nsIMsgFolder **folder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNthSearchScope(which, scopeId, folder); } \
  NS_IMETHOD AddScopeTerm(nsMsgSearchScopeValue scope, nsIMsgFolder *folder) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddScopeTerm(scope, folder); } \
  NS_IMETHOD AddDirectoryScopeTerm(nsMsgSearchScopeValue scope) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDirectoryScopeTerm(scope); } \
  NS_IMETHOD ClearScopes(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearScopes(); } \
  NS_IMETHOD ScopeUsesCustomHeaders(nsMsgSearchScopeValue scope, void * selection, PRBool forFilters, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ScopeUsesCustomHeaders(scope, selection, forFilters, _retval); } \
  NS_IMETHOD IsStringAttribute(nsMsgSearchAttribValue attrib, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsStringAttribute(attrib, _retval); } \
  NS_IMETHOD AddAllScopes(nsMsgSearchScopeValue attrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddAllScopes(attrib); } \
  NS_IMETHOD Search(nsIMsgWindow *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->Search(aWindow); } \
  NS_IMETHOD InterruptSearch(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->InterruptSearch(); } \
  NS_IMETHOD PauseSearch(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->PauseSearch(); } \
  NS_IMETHOD ResumeSearch(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ResumeSearch(); } \
  NS_IMETHOD GetSearchParam(void * *aSearchParam) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchParam(aSearchParam); } \
  NS_IMETHOD GetSearchType(nsMsgSearchType * *aSearchType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchType(aSearchType); } \
  NS_IMETHOD SetSearchParam(nsMsgSearchType *type, void * param, nsMsgSearchType **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSearchParam(type, param, _retval); } \
  NS_IMETHOD AddResultElement(nsMsgResultElement *element) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddResultElement(element); } \
  NS_IMETHOD MatchHdr(nsIMsgDBHdr *aMsgHdr, nsIMsgDatabase *aDatabase, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchHdr(aMsgHdr, aDatabase, _retval); } \
  NS_IMETHOD AddSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddSearchHit(header, folder); } \
  NS_IMETHOD GetNumResults(PRInt32 *aNumResults) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumResults(aNumResults); } \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWindow(aWindow); } \
  NS_IMETHOD SetWindow(nsIMsgWindow * aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWindow(aWindow); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchSession : public nsIMsgSearchSession
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHSESSION

  nsMsgSearchSession();

private:
  ~nsMsgSearchSession();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchSession, nsIMsgSearchSession)

nsMsgSearchSession::nsMsgSearchSession()
{
  /* member initializers and constructor code */
}

nsMsgSearchSession::~nsMsgSearchSession()
{
  /* destructor code */
}

/* void addSearchTerm (in nsMsgSearchAttribValue attrib, in nsMsgSearchOpValue op, in nsIMsgSearchValue value, in boolean BooleanAND, in string arbitraryHeader); */
NS_IMETHODIMP nsMsgSearchSession::AddSearchTerm(nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value, PRBool BooleanAND, const char *arbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsISupportsArray searchTerms; */
NS_IMETHODIMP nsMsgSearchSession::GetSearchTerms(nsISupportsArray * *aSearchTerms)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgSearchTerm createTerm (); */
NS_IMETHODIMP nsMsgSearchSession::CreateTerm(nsIMsgSearchTerm **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void appendTerm (in nsIMsgSearchTerm term); */
NS_IMETHODIMP nsMsgSearchSession::AppendTerm(nsIMsgSearchTerm *term)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void registerListener (in nsIMsgSearchNotify listener); */
NS_IMETHODIMP nsMsgSearchSession::RegisterListener(nsIMsgSearchNotify *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void unregisterListener (in nsIMsgSearchNotify listener); */
NS_IMETHODIMP nsMsgSearchSession::UnregisterListener(nsIMsgSearchNotify *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long numSearchTerms; */
NS_IMETHODIMP nsMsgSearchSession::GetNumSearchTerms(PRUint32 *aNumSearchTerms)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgSearchAdapter runningAdapter; */
NS_IMETHODIMP nsMsgSearchSession::GetRunningAdapter(nsIMsgSearchAdapter * *aRunningAdapter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getNthSearchTerm (in long whichTerm, in nsMsgSearchAttribValue attrib, in nsMsgSearchOpValue op, in nsIMsgSearchValue value); */
NS_IMETHODIMP nsMsgSearchSession::GetNthSearchTerm(PRInt32 whichTerm, nsMsgSearchAttribValue attrib, nsMsgSearchOpValue op, nsIMsgSearchValue *value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long countSearchScopes (); */
NS_IMETHODIMP nsMsgSearchSession::CountSearchScopes(PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getNthSearchScope (in long which, out nsMsgSearchScopeValue scopeId, out nsIMsgFolder folder); */
NS_IMETHODIMP nsMsgSearchSession::GetNthSearchScope(PRInt32 which, nsMsgSearchScopeValue *scopeId, nsIMsgFolder **folder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addScopeTerm (in nsMsgSearchScopeValue scope, in nsIMsgFolder folder); */
NS_IMETHODIMP nsMsgSearchSession::AddScopeTerm(nsMsgSearchScopeValue scope, nsIMsgFolder *folder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addDirectoryScopeTerm (in nsMsgSearchScopeValue scope); */
NS_IMETHODIMP nsMsgSearchSession::AddDirectoryScopeTerm(nsMsgSearchScopeValue scope)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearScopes (); */
NS_IMETHODIMP nsMsgSearchSession::ClearScopes()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] boolean ScopeUsesCustomHeaders (in nsMsgSearchScopeValue scope, in voidPtr selection, in boolean forFilters); */
NS_IMETHODIMP nsMsgSearchSession::ScopeUsesCustomHeaders(nsMsgSearchScopeValue scope, void * selection, PRBool forFilters, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean IsStringAttribute (in nsMsgSearchAttribValue attrib); */
NS_IMETHODIMP nsMsgSearchSession::IsStringAttribute(nsMsgSearchAttribValue attrib, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddAllScopes (in nsMsgSearchScopeValue attrib); */
NS_IMETHODIMP nsMsgSearchSession::AddAllScopes(nsMsgSearchScopeValue attrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void search (in nsIMsgWindow aWindow); */
NS_IMETHODIMP nsMsgSearchSession::Search(nsIMsgWindow *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void interruptSearch (); */
NS_IMETHODIMP nsMsgSearchSession::InterruptSearch()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void pauseSearch (); */
NS_IMETHODIMP nsMsgSearchSession::PauseSearch()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void resumeSearch (); */
NS_IMETHODIMP nsMsgSearchSession::ResumeSearch()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] readonly attribute voidPtr searchParam; */
NS_IMETHODIMP nsMsgSearchSession::GetSearchParam(void * *aSearchParam)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsMsgSearchType searchType; */
NS_IMETHODIMP nsMsgSearchSession::GetSearchType(nsMsgSearchType * *aSearchType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] nsMsgSearchType SetSearchParam (in nsMsgSearchType type, in voidPtr param); */
NS_IMETHODIMP nsMsgSearchSession::SetSearchParam(nsMsgSearchType *type, void * param, nsMsgSearchType **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void AddResultElement (in nsMsgResultElement element); */
NS_IMETHODIMP nsMsgSearchSession::AddResultElement(nsMsgResultElement *element)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean MatchHdr (in nsIMsgDBHdr aMsgHdr, in nsIMsgDatabase aDatabase); */
NS_IMETHODIMP nsMsgSearchSession::MatchHdr(nsIMsgDBHdr *aMsgHdr, nsIMsgDatabase *aDatabase, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addSearchHit (in nsIMsgDBHdr header, in nsIMsgFolder folder); */
NS_IMETHODIMP nsMsgSearchSession::AddSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numResults; */
NS_IMETHODIMP nsMsgSearchSession::GetNumResults(PRInt32 *aNumResults)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgWindow window; */
NS_IMETHODIMP nsMsgSearchSession::GetWindow(nsIMsgWindow * *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchSession::SetWindow(nsIMsgWindow * aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchSession_h__ */
