/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgFolderCache.idl
 */

#ifndef __gen_nsIMsgFolderCache_h__
#define __gen_nsIMsgFolderCache_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */

class nsIMsgFolderCacheElement; /* forward declaration */


/* starting interface:    nsIMsgFolderCache */
#define NS_IMSGFOLDERCACHE_IID_STR "a340a8c8-3587-4d7a-a2af-ed06b923d5ac"

#define NS_IMSGFOLDERCACHE_IID \
  {0xa340a8c8, 0x3587, 0x4d7a, \
    { 0xa2, 0xaf, 0xed, 0x06, 0xb9, 0x23, 0xd5, 0xac }}

class NS_NO_VTABLE nsIMsgFolderCache : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERCACHE_IID)

  /* void Init (in nsIFileSpec fileSpec); */
  NS_IMETHOD Init(nsIFileSpec *fileSpec) = 0;

  /* nsIMsgFolderCacheElement GetCacheElement (in string key, in boolean createIfMissing); */
  NS_IMETHOD GetCacheElement(const char *key, PRBool createIfMissing, nsIMsgFolderCacheElement **_retval) = 0;

  /* void clear (); */
  NS_IMETHOD Clear(void) = 0;

  /* void close (); */
  NS_IMETHOD Close(void) = 0;

  /* void commit (in boolean compress); */
  NS_IMETHOD Commit(PRBool compress) = 0;

  /* void removeElement (in string key); */
  NS_IMETHOD RemoveElement(const char *key) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERCACHE \
  NS_IMETHOD Init(nsIFileSpec *fileSpec); \
  NS_IMETHOD GetCacheElement(const char *key, PRBool createIfMissing, nsIMsgFolderCacheElement **_retval); \
  NS_IMETHOD Clear(void); \
  NS_IMETHOD Close(void); \
  NS_IMETHOD Commit(PRBool compress); \
  NS_IMETHOD RemoveElement(const char *key); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERCACHE(_to) \
  NS_IMETHOD Init(nsIFileSpec *fileSpec) { return _to Init(fileSpec); } \
  NS_IMETHOD GetCacheElement(const char *key, PRBool createIfMissing, nsIMsgFolderCacheElement **_retval) { return _to GetCacheElement(key, createIfMissing, _retval); } \
  NS_IMETHOD Clear(void) { return _to Clear(); } \
  NS_IMETHOD Close(void) { return _to Close(); } \
  NS_IMETHOD Commit(PRBool compress) { return _to Commit(compress); } \
  NS_IMETHOD RemoveElement(const char *key) { return _to RemoveElement(key); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERCACHE(_to) \
  NS_IMETHOD Init(nsIFileSpec *fileSpec) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(fileSpec); } \
  NS_IMETHOD GetCacheElement(const char *key, PRBool createIfMissing, nsIMsgFolderCacheElement **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCacheElement(key, createIfMissing, _retval); } \
  NS_IMETHOD Clear(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Clear(); } \
  NS_IMETHOD Close(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Close(); } \
  NS_IMETHOD Commit(PRBool compress) { return !_to ? NS_ERROR_NULL_POINTER : _to->Commit(compress); } \
  NS_IMETHOD RemoveElement(const char *key) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveElement(key); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderCache : public nsIMsgFolderCache
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERCACHE

  nsMsgFolderCache();

private:
  ~nsMsgFolderCache();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderCache, nsIMsgFolderCache)

nsMsgFolderCache::nsMsgFolderCache()
{
  /* member initializers and constructor code */
}

nsMsgFolderCache::~nsMsgFolderCache()
{
  /* destructor code */
}

/* void Init (in nsIFileSpec fileSpec); */
NS_IMETHODIMP nsMsgFolderCache::Init(nsIFileSpec *fileSpec)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgFolderCacheElement GetCacheElement (in string key, in boolean createIfMissing); */
NS_IMETHODIMP nsMsgFolderCache::GetCacheElement(const char *key, PRBool createIfMissing, nsIMsgFolderCacheElement **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clear (); */
NS_IMETHODIMP nsMsgFolderCache::Clear()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void close (); */
NS_IMETHODIMP nsMsgFolderCache::Close()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void commit (in boolean compress); */
NS_IMETHODIMP nsMsgFolderCache::Commit(PRBool compress)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeElement (in string key); */
NS_IMETHODIMP nsMsgFolderCache::RemoveElement(const char *key)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderCache_h__ */
