/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMailboxService.idl
 */

#ifndef __gen_nsIMailboxService_h__
#define __gen_nsIMailboxService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListener_h__
#include "nsIUrlListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIStreamListener; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

#include "nsFileSpec.h"

/* starting interface:    nsIMailboxService */
#define NS_IMAILBOXSERVICE_IID_STR "eef82460-cb69-11d2-8065-006008128c4e"

#define NS_IMAILBOXSERVICE_IID \
  {0xeef82460, 0xcb69, 0x11d2, \
    { 0x80, 0x65, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsIMailboxService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMAILBOXSERVICE_IID)

  /* [noscript] nsIURI ParseMailbox (in nsIMsgWindow aMsgWindow, in nsFileSpec aMailboxPath, in nsIStreamListener aMailboxParser, in nsIUrlListener aUrlListener); */
  NS_IMETHOD ParseMailbox(nsIMsgWindow *aMsgWindow, nsFileSpec & aMailboxPath, nsIStreamListener *aMailboxParser, nsIUrlListener *aUrlListener, nsIURI **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMAILBOXSERVICE \
  NS_IMETHOD ParseMailbox(nsIMsgWindow *aMsgWindow, nsFileSpec & aMailboxPath, nsIStreamListener *aMailboxParser, nsIUrlListener *aUrlListener, nsIURI **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMAILBOXSERVICE(_to) \
  NS_IMETHOD ParseMailbox(nsIMsgWindow *aMsgWindow, nsFileSpec & aMailboxPath, nsIStreamListener *aMailboxParser, nsIUrlListener *aUrlListener, nsIURI **_retval) { return _to ParseMailbox(aMsgWindow, aMailboxPath, aMailboxParser, aUrlListener, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMAILBOXSERVICE(_to) \
  NS_IMETHOD ParseMailbox(nsIMsgWindow *aMsgWindow, nsFileSpec & aMailboxPath, nsIStreamListener *aMailboxParser, nsIUrlListener *aUrlListener, nsIURI **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ParseMailbox(aMsgWindow, aMailboxPath, aMailboxParser, aUrlListener, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMailboxService : public nsIMailboxService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMAILBOXSERVICE

  nsMailboxService();

private:
  ~nsMailboxService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMailboxService, nsIMailboxService)

nsMailboxService::nsMailboxService()
{
  /* member initializers and constructor code */
}

nsMailboxService::~nsMailboxService()
{
  /* destructor code */
}

/* [noscript] nsIURI ParseMailbox (in nsIMsgWindow aMsgWindow, in nsFileSpec aMailboxPath, in nsIStreamListener aMailboxParser, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsMailboxService::ParseMailbox(nsIMsgWindow *aMsgWindow, nsFileSpec & aMailboxPath, nsIStreamListener *aMailboxParser, nsIUrlListener *aUrlListener, nsIURI **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMailboxService_h__ */
