/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsMsgFilterCore.idl
 */

#ifndef __gen_nsMsgFilterCore_h__
#define __gen_nsMsgFilterCore_h__


#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

#ifndef __gen_nsMsgSearchCore_h__
#include "nsMsgSearchCore.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef PRInt32 nsMsgFilterTypeType;


/* starting interface:    nsMsgFilterType */
#define NS_MSGFILTERTYPE_IID_STR "e9b548ba-304e-11d3-8b33-00a0c900d445"

#define NS_MSGFILTERTYPE_IID \
  {0xe9b548ba, 0x304e, 0x11d3, \
    { 0x8b, 0x33, 0x00, 0xa0, 0xc9, 0x00, 0xd4, 0x45 }}

class NS_NO_VTABLE nsMsgFilterType {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_MSGFILTERTYPE_IID)

  enum { InboxRule = 1 };

  enum { InboxJavaScript = 2 };

  enum { Inbox = 3 };

  enum { NewsRule = 4 };

  enum { NewsJavaScript = 8 };

  enum { News = 11 };

  enum { All = 15 };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGFILTERTYPE \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGFILTERTYPE(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGFILTERTYPE(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgFilterType
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGFILTERTYPE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgFilterType)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif

typedef PRInt32 nsMsgFilterMotionValue;

typedef PRInt32 nsMsgFilterIndex;

typedef PRInt32 nsMsgRuleActionType;


/* starting interface:    nsMsgFilterAction */
#define NS_MSGFILTERACTION_IID_STR "59af7696-1e28-4642-a400-fa327ae0b8d8"

#define NS_MSGFILTERACTION_IID \
  {0x59af7696, 0x1e28, 0x4642, \
    { 0xa4, 0x00, 0xfa, 0x32, 0x7a, 0xe0, 0xb8, 0xd8 }}

class NS_NO_VTABLE nsMsgFilterAction {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_MSGFILTERACTION_IID)

  enum { None = 0 };

  enum { MoveToFolder = 1 };

  enum { ChangePriority = 2 };

  enum { Delete = 3 };

  enum { MarkRead = 4 };

  enum { KillThread = 5 };

  enum { WatchThread = 6 };

  enum { MarkFlagged = 7 };

  enum { Label = 8 };

  enum { Reply = 9 };

  enum { Forward = 10 };

  enum { StopExecution = 11 };

  enum { DeleteFromPop3Server = 12 };

  enum { LeaveOnPop3Server = 13 };

  enum { JunkScore = 14 };

  enum { FetchBodyFromPop3Server = 15 };

  enum { CopyToFolder = 16 };

  enum { AddTag = 17 };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGFILTERACTION \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGFILTERACTION(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGFILTERACTION(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgFilterAction
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGFILTERACTION

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgFilterAction)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsMsgFilterCore_h__ */
