/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgStringService.idl
 */

#ifndef __gen_nsIMsgStringService_h__
#define __gen_nsIMsgStringService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIStringBundle_h__
#include "nsIStringBundle.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgStringService */
#define NS_IMSGSTRINGSERVICE_IID_STR "6ac107b1-d558-11d3-98b1-001083010e9b"

#define NS_IMSGSTRINGSERVICE_IID \
  {0x6ac107b1, 0xd558, 0x11d3, \
    { 0x98, 0xb1, 0x00, 0x10, 0x83, 0x01, 0x0e, 0x9b }}

class NS_NO_VTABLE nsIMsgStringService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSTRINGSERVICE_IID)

  /* wstring getStringByID (in long aStringID); */
  NS_IMETHOD GetStringByID(PRInt32 aStringID, PRUnichar **_retval) = 0;

  /* readonly attribute nsIStringBundle bundle; */
  NS_IMETHOD GetBundle(nsIStringBundle * *aBundle) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSTRINGSERVICE \
  NS_IMETHOD GetStringByID(PRInt32 aStringID, PRUnichar **_retval); \
  NS_IMETHOD GetBundle(nsIStringBundle * *aBundle); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSTRINGSERVICE(_to) \
  NS_IMETHOD GetStringByID(PRInt32 aStringID, PRUnichar **_retval) { return _to GetStringByID(aStringID, _retval); } \
  NS_IMETHOD GetBundle(nsIStringBundle * *aBundle) { return _to GetBundle(aBundle); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSTRINGSERVICE(_to) \
  NS_IMETHOD GetStringByID(PRInt32 aStringID, PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStringByID(aStringID, _retval); } \
  NS_IMETHOD GetBundle(nsIStringBundle * *aBundle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBundle(aBundle); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgStringService : public nsIMsgStringService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSTRINGSERVICE

  nsMsgStringService();

private:
  ~nsMsgStringService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgStringService, nsIMsgStringService)

nsMsgStringService::nsMsgStringService()
{
  /* member initializers and constructor code */
}

nsMsgStringService::~nsMsgStringService()
{
  /* destructor code */
}

/* wstring getStringByID (in long aStringID); */
NS_IMETHODIMP nsMsgStringService::GetStringByID(PRInt32 aStringID, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIStringBundle bundle; */
NS_IMETHODIMP nsMsgStringService::GetBundle(nsIStringBundle * *aBundle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define NS_MAILNEWS_STRINGSERVICE_CONTRACTID      "@mozilla.org/messenger/stringservice;1"
#define NS_MAILNEWS_STRINGSERVICE_CONTRACTID_PREFIX NS_MAILNEWS_STRINGSERVICE_CONTRACTID"?type="

#endif /* __gen_nsIMsgStringService_h__ */
