/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMessengerMigrator.idl
 */

#ifndef __gen_nsIMessengerMigrator_h__
#define __gen_nsIMessengerMigrator_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgIdentity_h__
#include "nsIMsgIdentity.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMessengerMigrator */
#define NS_IMESSENGERMIGRATOR_IID_STR "54818d98-1dd2-11b2-82aa-a9197f997503"

#define NS_IMESSENGERMIGRATOR_IID \
  {0x54818d98, 0x1dd2, 0x11b2, \
    { 0x82, 0xaa, 0xa9, 0x19, 0x7f, 0x99, 0x75, 0x03 }}

class NS_NO_VTABLE nsIMessengerMigrator : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMESSENGERMIGRATOR_IID)

  /* void UpgradePrefs (); */
  NS_IMETHOD UpgradePrefs(void) = 0;

  /* void createLocalMailAccount (in boolean migrating); */
  NS_IMETHOD CreateLocalMailAccount(PRBool migrating) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMESSENGERMIGRATOR \
  NS_IMETHOD UpgradePrefs(void); \
  NS_IMETHOD CreateLocalMailAccount(PRBool migrating); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMESSENGERMIGRATOR(_to) \
  NS_IMETHOD UpgradePrefs(void) { return _to UpgradePrefs(); } \
  NS_IMETHOD CreateLocalMailAccount(PRBool migrating) { return _to CreateLocalMailAccount(migrating); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMESSENGERMIGRATOR(_to) \
  NS_IMETHOD UpgradePrefs(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->UpgradePrefs(); } \
  NS_IMETHOD CreateLocalMailAccount(PRBool migrating) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateLocalMailAccount(migrating); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMessengerMigrator : public nsIMessengerMigrator
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMESSENGERMIGRATOR

  nsMessengerMigrator();

private:
  ~nsMessengerMigrator();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMessengerMigrator, nsIMessengerMigrator)

nsMessengerMigrator::nsMessengerMigrator()
{
  /* member initializers and constructor code */
}

nsMessengerMigrator::~nsMessengerMigrator()
{
  /* destructor code */
}

/* void UpgradePrefs (); */
NS_IMETHODIMP nsMessengerMigrator::UpgradePrefs()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void createLocalMailAccount (in boolean migrating); */
NS_IMETHODIMP nsMessengerMigrator::CreateLocalMailAccount(PRBool migrating)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMessengerMigrator_h__ */
