/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla mailnews.
 *
 * The Initial Developer of the Original Code is
 * David Bienvenu <bienvenu@mozilla.org>.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsIMsgFolder;
interface nsIUrlListener;
interface nsIMsgWindow;

[scriptable, uuid(c1c47796-c8b0-4d12-97aa-c93883ea1c97)]
interface nsINewsBlogFeedDownloader : nsISupports
{
  void downloadFeed(in string aUrl, in nsIMsgFolder aFolder,
                     in boolean aQuickMode, in wstring aTitle,  
					in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow);

  /* A convient method to subscribe to feeds without going through the subscribe UI
     used by drag and drop */
  void subscribeToFeed(in string aUrl, in nsIMsgFolder aFolder, in nsIMsgWindow aMsgWindow);
  
  /* called when the RSS Incoming Server detects a change to an RSS folder. For instance, the user just
     deleted an RSS folder and we need to update the subscriptions data source. Or the user renamed an RSS folder...
  */
  void updateSubscriptionsDS(in nsIMsgFolder aFolder, in boolean aUnsubscribe);
};

