/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "MailNewsTypes2.idl"
#include "nsIFileSpec.idl"

interface nsIStreamListener;
interface nsIMsgDBHdr;
%{C++
#include "nsIStreamListener.h"
%}

typedef long nsMailboxAction;

[scriptable, uuid(AE30B004-320C-4D2B-AB52-45D2C2DC2CCE)]
interface nsIMailboxUrl : nsISupports {

	// Mailbox urls which parse a mailbox folder require a consumer of the
    // stream which will represent the mailbox. This consumer is the mailbox
    // parser. As data from the mailbox folder is read in, the data will be
    // written to a stream and the consumer will be notified through
    // nsIStreamListenter::OnDataAvailable that the stream has data
	// available...
	// mscott: I wonder if the caller should be allowed to create and set
    // the stream they want the data written to as well? Hmm....
	
    attribute nsIStreamListener mailboxParser;
    
	/////////////////////////////////////////////////////////////////////////
	// Copy/Move mailbox urls require a mailbox copy handler which actually
    // performs the copy.
	/////////////////////////////////////////////////////////////////////////
    attribute nsIStreamListener mailboxCopyHandler;

    // mailbox URL state
    [noscript] readonly attribute nsFileSpecPtr fileSpec;

    // Some mailbox urls include a message key for the message in question.
    readonly attribute nsMsgKey messageKey;
    
    // this is to support multiple msg move/copy in one url
    void setMoveCopyMsgKeys(out nsMsgKey keysToFlag, in long numKeys);
    void getMoveCopyMsgHdrForIndex(in unsigned long msgIndex, out nsIMsgDBHdr msgHdr);
    readonly attribute unsigned long numMoveCopyMsgs;
    attribute unsigned long curMoveCopyMsgIndex;
	// mailbox urls to fetch a mail message can specify the size of
    // the message...
	// this saves us the trouble of having to open up the msg db and ask
    // ourselves...
    attribute unsigned long messageSize;
    
    attribute nsMailboxAction mailboxAction;

    /* these are nsMailboxActions */
	const long ActionParseMailbox = 0;
    const long ActionFetchMessage = 1;
    const long ActionCopyMessage = 2;
	const long ActionMoveMessage = 3;
	const long ActionSaveMessageToDisk = 4;
	const long ActionAppendMessageToDisk = 5;
	const long ActionFetchPart = 6;
};

