/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIUrlClassifierStreamUpdater.idl
 */

#ifndef __gen_nsIUrlClassifierStreamUpdater_h__
#define __gen_nsIUrlClassifierStreamUpdater_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlClassifierDBService_h__
#include "nsIUrlClassifierDBService.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIUrlClassifierStreamUpdater */
#define NS_IURLCLASSIFIERSTREAMUPDATER_IID_STR "d9277fa4-7d51-4175-bd4e-546c080a83bf"

#define NS_IURLCLASSIFIERSTREAMUPDATER_IID \
  {0xd9277fa4, 0x7d51, 0x4175, \
    { 0xbd, 0x4e, 0x54, 0x6c, 0x08, 0x0a, 0x83, 0xbf }}

/**
 * This is a class to manage large table updates from the server.  Rather than
 * downloading the whole update and then updating the sqlite database, we
 * update tables as the data is streaming in.
 */
class NS_NO_VTABLE nsIUrlClassifierStreamUpdater : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IURLCLASSIFIERSTREAMUPDATER_IID)

  /**
   * The Url to download from.  Should be plain ascii text.
   */
  /* attribute ACString updateUrl; */
  NS_IMETHOD GetUpdateUrl(nsACString & aUpdateUrl) = 0;
  NS_IMETHOD SetUpdateUrl(const nsACString & aUpdateUrl) = 0;

  /**
   * Try to download updates from updateUrl.  Only one instance of this
   * runs at a time, so we return false if another instance is already
   * running.
   * @param aTableCallback Called once for each table that we successfully
   *     download with the table header as the parameter.
   * @param aErrorCallback Called if we get an http error or a connection
   *   refused.
   */
  /* boolean downloadUpdates (in nsIUrlClassifierCallback aTableCallback, in nsIUrlClassifierCallback aErrorCallback); */
  NS_IMETHOD DownloadUpdates(nsIUrlClassifierCallback *aTableCallback, nsIUrlClassifierCallback *aErrorCallback, PRBool *_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLCLASSIFIERSTREAMUPDATER \
  NS_IMETHOD GetUpdateUrl(nsACString & aUpdateUrl); \
  NS_IMETHOD SetUpdateUrl(const nsACString & aUpdateUrl); \
  NS_IMETHOD DownloadUpdates(nsIUrlClassifierCallback *aTableCallback, nsIUrlClassifierCallback *aErrorCallback, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLCLASSIFIERSTREAMUPDATER(_to) \
  NS_IMETHOD GetUpdateUrl(nsACString & aUpdateUrl) { return _to GetUpdateUrl(aUpdateUrl); } \
  NS_IMETHOD SetUpdateUrl(const nsACString & aUpdateUrl) { return _to SetUpdateUrl(aUpdateUrl); } \
  NS_IMETHOD DownloadUpdates(nsIUrlClassifierCallback *aTableCallback, nsIUrlClassifierCallback *aErrorCallback, PRBool *_retval) { return _to DownloadUpdates(aTableCallback, aErrorCallback, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLCLASSIFIERSTREAMUPDATER(_to) \
  NS_IMETHOD GetUpdateUrl(nsACString & aUpdateUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUpdateUrl(aUpdateUrl); } \
  NS_IMETHOD SetUpdateUrl(const nsACString & aUpdateUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUpdateUrl(aUpdateUrl); } \
  NS_IMETHOD DownloadUpdates(nsIUrlClassifierCallback *aTableCallback, nsIUrlClassifierCallback *aErrorCallback, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DownloadUpdates(aTableCallback, aErrorCallback, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsUrlClassifierStreamUpdater : public nsIUrlClassifierStreamUpdater
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLCLASSIFIERSTREAMUPDATER

  nsUrlClassifierStreamUpdater();

private:
  ~nsUrlClassifierStreamUpdater();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsUrlClassifierStreamUpdater, nsIUrlClassifierStreamUpdater)

nsUrlClassifierStreamUpdater::nsUrlClassifierStreamUpdater()
{
  /* member initializers and constructor code */
}

nsUrlClassifierStreamUpdater::~nsUrlClassifierStreamUpdater()
{
  /* destructor code */
}

/* attribute ACString updateUrl; */
NS_IMETHODIMP nsUrlClassifierStreamUpdater::GetUpdateUrl(nsACString & aUpdateUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsUrlClassifierStreamUpdater::SetUpdateUrl(const nsACString & aUpdateUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean downloadUpdates (in nsIUrlClassifierCallback aTableCallback, in nsIUrlClassifierCallback aErrorCallback); */
NS_IMETHODIMP nsUrlClassifierStreamUpdater::DownloadUpdates(nsIUrlClassifierCallback *aTableCallback, nsIUrlClassifierCallback *aErrorCallback, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIUrlClassifierStreamUpdater_h__ */
