/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgProtocolInfo.idl
 */

#ifndef __gen_nsIMsgProtocolInfo_h__
#define __gen_nsIMsgProtocolInfo_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */

#define NS_MSGPROTOCOLINFO_CONTRACTID_PREFIX \
  "@mozilla.org/messenger/protocol/info;1?type="

/* starting interface:    nsIMsgProtocolInfo */
#define NS_IMSGPROTOCOLINFO_IID_STR "53d0214a-689c-11d3-80f5-00a0c900d445"

#define NS_IMSGPROTOCOLINFO_IID \
  {0x53d0214a, 0x689c, 0x11d3, \
    { 0x80, 0xf5, 0x00, 0xa0, 0xc9, 0x00, 0xd4, 0x45 }}

class NS_NO_VTABLE nsIMsgProtocolInfo : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGPROTOCOLINFO_IID)

  /**
     * the default path to store local data for this type of
     * server. Each server is usually in a subdirectory below this
     */
  /* attribute nsIFileSpec defaultLocalPath; */
  NS_IMETHOD GetDefaultLocalPath(nsIFileSpec * *aDefaultLocalPath) = 0;
  NS_IMETHOD SetDefaultLocalPath(nsIFileSpec * aDefaultLocalPath) = 0;

  /**
     * the IID of the protocol-specific interface for this server
     * usually used from JS to dynamically get server-specific attributes
     */
  /* readonly attribute nsIIDPtr serverIID; */
  NS_IMETHOD GetServerIID(nsIID * *aServerIID) = 0;

  /**
     * does this server type require a username?
     * for instance, news does not but IMAP/POP do
     */
  /* readonly attribute boolean requiresUsername; */
  NS_IMETHOD GetRequiresUsername(PRBool *aRequiresUsername) = 0;

  /**
     * if the pretty name of the server should
     * just be the e-mail address. Otherwise it usually
     * ends up being something like "news on hostname"
     */
  /* readonly attribute boolean preflightPrettyNameWithEmailAddress; */
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(PRBool *aPreflightPrettyNameWithEmailAddress) = 0;

  /**
     * can this type of server be removed from the account manager?
     * for instance, local mail is not removable
     */
  /* readonly attribute boolean canDelete; */
  NS_IMETHOD GetCanDelete(PRBool *aCanDelete) = 0;

  /**
     * can this type of server log in at startup?
     */
  /* readonly attribute boolean canLoginAtStartUp; */
  NS_IMETHOD GetCanLoginAtStartUp(PRBool *aCanLoginAtStartUp) = 0;

  /**
     * can you duplicate this server?
     * for instance, local mail is unique and should not be duplicated.
     */
  /* readonly attribute boolean canDuplicate; */
  NS_IMETHOD GetCanDuplicate(PRBool *aCanDuplicate) = 0;

  /* long getDefaultServerPort (in boolean isSecure); */
  NS_IMETHOD GetDefaultServerPort(PRBool isSecure, PRInt32 *_retval) = 0;

  /**
     * An attribute that tell us whether on not we can 
     * get messages for the given server type 
	 * this is poorly named right now.
	 * it's really is there an inbox for this type?
	 * XXX todo, rename this.
     */
  /* readonly attribute boolean canGetMessages; */
  NS_IMETHOD GetCanGetMessages(PRBool *aCanGetMessages) = 0;

  /** 
	 * do messages arrive for this server
	 * if they do, we can use our junk controls on it.
	 */
  /* readonly attribute boolean canGetIncomingMessages; */
  NS_IMETHOD GetCanGetIncomingMessages(PRBool *aCanGetIncomingMessages) = 0;

  /**
     * do biff by default?
     */
  /* readonly attribute boolean defaultDoBiff; */
  NS_IMETHOD GetDefaultDoBiff(PRBool *aDefaultDoBiff) = 0;

  /**
     * do we need to show compose message link in the AccountCentral page ? 
     */
  /* readonly attribute boolean showComposeMsgLink; */
  NS_IMETHOD GetShowComposeMsgLink(PRBool *aShowComposeMsgLink) = 0;

  /**
     * do we need to build special folder URIs ? In case of IMAP, special folders
     * like 'Sent', 'Drafts' and 'Templates' are not created unless needed.
     * But, we do need to create folder URIs to reflect the choices in the UI in
     * copies and folders settings panel.
     */
  /* readonly attribute boolean needToBuildSpecialFolderURIs; */
  NS_IMETHOD GetNeedToBuildSpecialFolderURIs(PRBool *aNeedToBuildSpecialFolderURIs) = 0;

  /**
     * do we allow special folder deletion ?
     */
  /* readonly attribute boolean specialFoldersDeletionAllowed; */
  NS_IMETHOD GetSpecialFoldersDeletionAllowed(PRBool *aSpecialFoldersDeletionAllowed) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPROTOCOLINFO \
  NS_IMETHOD GetDefaultLocalPath(nsIFileSpec * *aDefaultLocalPath); \
  NS_IMETHOD SetDefaultLocalPath(nsIFileSpec * aDefaultLocalPath); \
  NS_IMETHOD GetServerIID(nsIID * *aServerIID); \
  NS_IMETHOD GetRequiresUsername(PRBool *aRequiresUsername); \
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(PRBool *aPreflightPrettyNameWithEmailAddress); \
  NS_IMETHOD GetCanDelete(PRBool *aCanDelete); \
  NS_IMETHOD GetCanLoginAtStartUp(PRBool *aCanLoginAtStartUp); \
  NS_IMETHOD GetCanDuplicate(PRBool *aCanDuplicate); \
  NS_IMETHOD GetDefaultServerPort(PRBool isSecure, PRInt32 *_retval); \
  NS_IMETHOD GetCanGetMessages(PRBool *aCanGetMessages); \
  NS_IMETHOD GetCanGetIncomingMessages(PRBool *aCanGetIncomingMessages); \
  NS_IMETHOD GetDefaultDoBiff(PRBool *aDefaultDoBiff); \
  NS_IMETHOD GetShowComposeMsgLink(PRBool *aShowComposeMsgLink); \
  NS_IMETHOD GetNeedToBuildSpecialFolderURIs(PRBool *aNeedToBuildSpecialFolderURIs); \
  NS_IMETHOD GetSpecialFoldersDeletionAllowed(PRBool *aSpecialFoldersDeletionAllowed); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPROTOCOLINFO(_to) \
  NS_IMETHOD GetDefaultLocalPath(nsIFileSpec * *aDefaultLocalPath) { return _to GetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD SetDefaultLocalPath(nsIFileSpec * aDefaultLocalPath) { return _to SetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD GetServerIID(nsIID * *aServerIID) { return _to GetServerIID(aServerIID); } \
  NS_IMETHOD GetRequiresUsername(PRBool *aRequiresUsername) { return _to GetRequiresUsername(aRequiresUsername); } \
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(PRBool *aPreflightPrettyNameWithEmailAddress) { return _to GetPreflightPrettyNameWithEmailAddress(aPreflightPrettyNameWithEmailAddress); } \
  NS_IMETHOD GetCanDelete(PRBool *aCanDelete) { return _to GetCanDelete(aCanDelete); } \
  NS_IMETHOD GetCanLoginAtStartUp(PRBool *aCanLoginAtStartUp) { return _to GetCanLoginAtStartUp(aCanLoginAtStartUp); } \
  NS_IMETHOD GetCanDuplicate(PRBool *aCanDuplicate) { return _to GetCanDuplicate(aCanDuplicate); } \
  NS_IMETHOD GetDefaultServerPort(PRBool isSecure, PRInt32 *_retval) { return _to GetDefaultServerPort(isSecure, _retval); } \
  NS_IMETHOD GetCanGetMessages(PRBool *aCanGetMessages) { return _to GetCanGetMessages(aCanGetMessages); } \
  NS_IMETHOD GetCanGetIncomingMessages(PRBool *aCanGetIncomingMessages) { return _to GetCanGetIncomingMessages(aCanGetIncomingMessages); } \
  NS_IMETHOD GetDefaultDoBiff(PRBool *aDefaultDoBiff) { return _to GetDefaultDoBiff(aDefaultDoBiff); } \
  NS_IMETHOD GetShowComposeMsgLink(PRBool *aShowComposeMsgLink) { return _to GetShowComposeMsgLink(aShowComposeMsgLink); } \
  NS_IMETHOD GetNeedToBuildSpecialFolderURIs(PRBool *aNeedToBuildSpecialFolderURIs) { return _to GetNeedToBuildSpecialFolderURIs(aNeedToBuildSpecialFolderURIs); } \
  NS_IMETHOD GetSpecialFoldersDeletionAllowed(PRBool *aSpecialFoldersDeletionAllowed) { return _to GetSpecialFoldersDeletionAllowed(aSpecialFoldersDeletionAllowed); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPROTOCOLINFO(_to) \
  NS_IMETHOD GetDefaultLocalPath(nsIFileSpec * *aDefaultLocalPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD SetDefaultLocalPath(nsIFileSpec * aDefaultLocalPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD GetServerIID(nsIID * *aServerIID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerIID(aServerIID); } \
  NS_IMETHOD GetRequiresUsername(PRBool *aRequiresUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRequiresUsername(aRequiresUsername); } \
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(PRBool *aPreflightPrettyNameWithEmailAddress) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPreflightPrettyNameWithEmailAddress(aPreflightPrettyNameWithEmailAddress); } \
  NS_IMETHOD GetCanDelete(PRBool *aCanDelete) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanDelete(aCanDelete); } \
  NS_IMETHOD GetCanLoginAtStartUp(PRBool *aCanLoginAtStartUp) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanLoginAtStartUp(aCanLoginAtStartUp); } \
  NS_IMETHOD GetCanDuplicate(PRBool *aCanDuplicate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanDuplicate(aCanDuplicate); } \
  NS_IMETHOD GetDefaultServerPort(PRBool isSecure, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultServerPort(isSecure, _retval); } \
  NS_IMETHOD GetCanGetMessages(PRBool *aCanGetMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanGetMessages(aCanGetMessages); } \
  NS_IMETHOD GetCanGetIncomingMessages(PRBool *aCanGetIncomingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanGetIncomingMessages(aCanGetIncomingMessages); } \
  NS_IMETHOD GetDefaultDoBiff(PRBool *aDefaultDoBiff) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultDoBiff(aDefaultDoBiff); } \
  NS_IMETHOD GetShowComposeMsgLink(PRBool *aShowComposeMsgLink) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShowComposeMsgLink(aShowComposeMsgLink); } \
  NS_IMETHOD GetNeedToBuildSpecialFolderURIs(PRBool *aNeedToBuildSpecialFolderURIs) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedToBuildSpecialFolderURIs(aNeedToBuildSpecialFolderURIs); } \
  NS_IMETHOD GetSpecialFoldersDeletionAllowed(PRBool *aSpecialFoldersDeletionAllowed) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSpecialFoldersDeletionAllowed(aSpecialFoldersDeletionAllowed); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgProtocolInfo : public nsIMsgProtocolInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPROTOCOLINFO

  nsMsgProtocolInfo();

private:
  ~nsMsgProtocolInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgProtocolInfo, nsIMsgProtocolInfo)

nsMsgProtocolInfo::nsMsgProtocolInfo()
{
  /* member initializers and constructor code */
}

nsMsgProtocolInfo::~nsMsgProtocolInfo()
{
  /* destructor code */
}

/* attribute nsIFileSpec defaultLocalPath; */
NS_IMETHODIMP nsMsgProtocolInfo::GetDefaultLocalPath(nsIFileSpec * *aDefaultLocalPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgProtocolInfo::SetDefaultLocalPath(nsIFileSpec * aDefaultLocalPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIIDPtr serverIID; */
NS_IMETHODIMP nsMsgProtocolInfo::GetServerIID(nsIID * *aServerIID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean requiresUsername; */
NS_IMETHODIMP nsMsgProtocolInfo::GetRequiresUsername(PRBool *aRequiresUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean preflightPrettyNameWithEmailAddress; */
NS_IMETHODIMP nsMsgProtocolInfo::GetPreflightPrettyNameWithEmailAddress(PRBool *aPreflightPrettyNameWithEmailAddress)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canDelete; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanDelete(PRBool *aCanDelete)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canLoginAtStartUp; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanLoginAtStartUp(PRBool *aCanLoginAtStartUp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canDuplicate; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanDuplicate(PRBool *aCanDuplicate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getDefaultServerPort (in boolean isSecure); */
NS_IMETHODIMP nsMsgProtocolInfo::GetDefaultServerPort(PRBool isSecure, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canGetMessages; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanGetMessages(PRBool *aCanGetMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canGetIncomingMessages; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanGetIncomingMessages(PRBool *aCanGetIncomingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean defaultDoBiff; */
NS_IMETHODIMP nsMsgProtocolInfo::GetDefaultDoBiff(PRBool *aDefaultDoBiff)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean showComposeMsgLink; */
NS_IMETHODIMP nsMsgProtocolInfo::GetShowComposeMsgLink(PRBool *aShowComposeMsgLink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean needToBuildSpecialFolderURIs; */
NS_IMETHODIMP nsMsgProtocolInfo::GetNeedToBuildSpecialFolderURIs(PRBool *aNeedToBuildSpecialFolderURIs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean specialFoldersDeletionAllowed; */
NS_IMETHODIMP nsMsgProtocolInfo::GetSpecialFoldersDeletionAllowed(PRBool *aSpecialFoldersDeletionAllowed)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgProtocolInfo_h__ */
