/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgComposeSecure.idl
 */

#ifndef __gen_nsIMsgComposeSecure_h__
#define __gen_nsIMsgComposeSecure_h__


#ifndef __gen_nsIMsgSendReport_h__
#include "nsIMsgSendReport.h"
#endif

#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgCompFields; /* forward declaration */

class nsIMsgIdentity; /* forward declaration */

class nsOutputFileStream;

/* starting interface:    nsIMsgComposeSecure */
#define NS_IMSGCOMPOSESECURE_IID_STR "ed899511-b473-4a93-ba02-d8cb90d58e1c"

#define NS_IMSGCOMPOSESECURE_IID \
  {0xed899511, 0xb473, 0x4a93, \
    { 0xba, 0x02, 0xd8, 0xcb, 0x90, 0xd5, 0x8e, 0x1c }}

class NS_NO_VTABLE nsIMsgComposeSecure : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGCOMPOSESECURE_IID)

  /* boolean requiresCryptoEncapsulation (in nsIMsgIdentity aIdentity, in nsIMsgCompFields aCompFields); */
  NS_IMETHOD RequiresCryptoEncapsulation(nsIMsgIdentity *aIdentity, nsIMsgCompFields *aCompFields, PRBool *_retval) = 0;

  /* void beginCryptoEncapsulation (in nsOutputFileStream aStream, in string aRecipients, in nsIMsgCompFields aCompFields, in nsIMsgIdentity aIdentity, in nsIMsgSendReport sendReport, in boolean aIsDraft); */
  NS_IMETHOD BeginCryptoEncapsulation(nsOutputFileStream * aStream, const char *aRecipients, nsIMsgCompFields *aCompFields, nsIMsgIdentity *aIdentity, nsIMsgSendReport *sendReport, PRBool aIsDraft) = 0;

  /* void finishCryptoEncapsulation (in boolean aAbort, in nsIMsgSendReport sendReport); */
  NS_IMETHOD FinishCryptoEncapsulation(PRBool aAbort, nsIMsgSendReport *sendReport) = 0;

  /* void mimeCryptoWriteBlock (in string aBuf, in long aLen); */
  NS_IMETHOD MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGCOMPOSESECURE \
  NS_IMETHOD RequiresCryptoEncapsulation(nsIMsgIdentity *aIdentity, nsIMsgCompFields *aCompFields, PRBool *_retval); \
  NS_IMETHOD BeginCryptoEncapsulation(nsOutputFileStream * aStream, const char *aRecipients, nsIMsgCompFields *aCompFields, nsIMsgIdentity *aIdentity, nsIMsgSendReport *sendReport, PRBool aIsDraft); \
  NS_IMETHOD FinishCryptoEncapsulation(PRBool aAbort, nsIMsgSendReport *sendReport); \
  NS_IMETHOD MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGCOMPOSESECURE(_to) \
  NS_IMETHOD RequiresCryptoEncapsulation(nsIMsgIdentity *aIdentity, nsIMsgCompFields *aCompFields, PRBool *_retval) { return _to RequiresCryptoEncapsulation(aIdentity, aCompFields, _retval); } \
  NS_IMETHOD BeginCryptoEncapsulation(nsOutputFileStream * aStream, const char *aRecipients, nsIMsgCompFields *aCompFields, nsIMsgIdentity *aIdentity, nsIMsgSendReport *sendReport, PRBool aIsDraft) { return _to BeginCryptoEncapsulation(aStream, aRecipients, aCompFields, aIdentity, sendReport, aIsDraft); } \
  NS_IMETHOD FinishCryptoEncapsulation(PRBool aAbort, nsIMsgSendReport *sendReport) { return _to FinishCryptoEncapsulation(aAbort, sendReport); } \
  NS_IMETHOD MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen) { return _to MimeCryptoWriteBlock(aBuf, aLen); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGCOMPOSESECURE(_to) \
  NS_IMETHOD RequiresCryptoEncapsulation(nsIMsgIdentity *aIdentity, nsIMsgCompFields *aCompFields, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->RequiresCryptoEncapsulation(aIdentity, aCompFields, _retval); } \
  NS_IMETHOD BeginCryptoEncapsulation(nsOutputFileStream * aStream, const char *aRecipients, nsIMsgCompFields *aCompFields, nsIMsgIdentity *aIdentity, nsIMsgSendReport *sendReport, PRBool aIsDraft) { return !_to ? NS_ERROR_NULL_POINTER : _to->BeginCryptoEncapsulation(aStream, aRecipients, aCompFields, aIdentity, sendReport, aIsDraft); } \
  NS_IMETHOD FinishCryptoEncapsulation(PRBool aAbort, nsIMsgSendReport *sendReport) { return !_to ? NS_ERROR_NULL_POINTER : _to->FinishCryptoEncapsulation(aAbort, sendReport); } \
  NS_IMETHOD MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen) { return !_to ? NS_ERROR_NULL_POINTER : _to->MimeCryptoWriteBlock(aBuf, aLen); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgComposeSecure : public nsIMsgComposeSecure
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGCOMPOSESECURE

  nsMsgComposeSecure();

private:
  ~nsMsgComposeSecure();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgComposeSecure, nsIMsgComposeSecure)

nsMsgComposeSecure::nsMsgComposeSecure()
{
  /* member initializers and constructor code */
}

nsMsgComposeSecure::~nsMsgComposeSecure()
{
  /* destructor code */
}

/* boolean requiresCryptoEncapsulation (in nsIMsgIdentity aIdentity, in nsIMsgCompFields aCompFields); */
NS_IMETHODIMP nsMsgComposeSecure::RequiresCryptoEncapsulation(nsIMsgIdentity *aIdentity, nsIMsgCompFields *aCompFields, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void beginCryptoEncapsulation (in nsOutputFileStream aStream, in string aRecipients, in nsIMsgCompFields aCompFields, in nsIMsgIdentity aIdentity, in nsIMsgSendReport sendReport, in boolean aIsDraft); */
NS_IMETHODIMP nsMsgComposeSecure::BeginCryptoEncapsulation(nsOutputFileStream * aStream, const char *aRecipients, nsIMsgCompFields *aCompFields, nsIMsgIdentity *aIdentity, nsIMsgSendReport *sendReport, PRBool aIsDraft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void finishCryptoEncapsulation (in boolean aAbort, in nsIMsgSendReport sendReport); */
NS_IMETHODIMP nsMsgComposeSecure::FinishCryptoEncapsulation(PRBool aAbort, nsIMsgSendReport *sendReport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void mimeCryptoWriteBlock (in string aBuf, in long aLen); */
NS_IMETHODIMP nsMsgComposeSecure::MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgComposeSecure_h__ */
