/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 * 
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the mozilla.org LDAP XPCOM SDK.
 *
 * The Initial Developer of the Original Code is
 * Oracle Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Dan Mosedale <dan.mosedale@oracle.com> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsILDAPBERValue;

/**
 * XPCOM representation of the C SDK LDAPControl structure.
 */
[scriptable, uuid(3a7ceb8e-482a-4a4f-9aa4-26b9a69a3595)]
interface nsILDAPControl : nsISupports
{
  /**
   * Control type, represented as a string.
   *
   * @exceptions   none
   */
  attribute ACString oid;

  /**
   * The data associated with a control, if any.  To specify that no data 
   * is to be associated with the control, don't set this at all (which
   * is equivalent to setting it to null).  
   *
   * @note Specifying a zero-length value is not currently supported.  At some
   * date, setting this to an nsILDAPBERValue which has not had any of the
   * set methods called will be the appropriate way to do that.
   *
   * @exceptions   none
   */
  attribute nsILDAPBERValue value;

  /**
   * Should the client or server abort if the control is not understood?
   * Should be set to false for server controls used in abandon and unbind
   * operations, since those have no server response.
   *
   * @exceptions   none
   */
  attribute boolean isCritical;
};
