/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsISimpleMimeConverter.idl
 */

#ifndef __gen_nsISimpleMimeConverter_h__
#define __gen_nsISimpleMimeConverter_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */


/* starting interface:    nsISimpleMimeConverter */
#define NS_ISIMPLEMIMECONVERTER_IID_STR "fc6e8234-bbf3-44a1-9802-5f023a929173"

#define NS_ISIMPLEMIMECONVERTER_IID \
  {0xfc6e8234, 0xbbf3, 0x44a1, \
    { 0x98, 0x02, 0x5f, 0x02, 0x3a, 0x92, 0x91, 0x73 }}

class NS_NO_VTABLE nsISimpleMimeConverter : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISIMPLEMIMECONVERTER_IID)

  /* attribute nsIURI uri; */
  NS_IMETHOD GetUri(nsIURI * *aUri) = 0;
  NS_IMETHOD SetUri(nsIURI * aUri) = 0;

  /* AUTF8String convertToHTML (in ACString contentType, in AUTF8String data); */
  NS_IMETHOD ConvertToHTML(const nsACString & contentType, const nsACString & data, nsACString & _retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISIMPLEMIMECONVERTER \
  NS_IMETHOD GetUri(nsIURI * *aUri); \
  NS_IMETHOD SetUri(nsIURI * aUri); \
  NS_IMETHOD ConvertToHTML(const nsACString & contentType, const nsACString & data, nsACString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISIMPLEMIMECONVERTER(_to) \
  NS_IMETHOD GetUri(nsIURI * *aUri) { return _to GetUri(aUri); } \
  NS_IMETHOD SetUri(nsIURI * aUri) { return _to SetUri(aUri); } \
  NS_IMETHOD ConvertToHTML(const nsACString & contentType, const nsACString & data, nsACString & _retval) { return _to ConvertToHTML(contentType, data, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISIMPLEMIMECONVERTER(_to) \
  NS_IMETHOD GetUri(nsIURI * *aUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUri(aUri); } \
  NS_IMETHOD SetUri(nsIURI * aUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUri(aUri); } \
  NS_IMETHOD ConvertToHTML(const nsACString & contentType, const nsACString & data, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ConvertToHTML(contentType, data, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSimpleMimeConverter : public nsISimpleMimeConverter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISIMPLEMIMECONVERTER

  nsSimpleMimeConverter();

private:
  ~nsSimpleMimeConverter();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSimpleMimeConverter, nsISimpleMimeConverter)

nsSimpleMimeConverter::nsSimpleMimeConverter()
{
  /* member initializers and constructor code */
}

nsSimpleMimeConverter::~nsSimpleMimeConverter()
{
  /* destructor code */
}

/* attribute nsIURI uri; */
NS_IMETHODIMP nsSimpleMimeConverter::GetUri(nsIURI * *aUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSimpleMimeConverter::SetUri(nsIURI * aUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AUTF8String convertToHTML (in ACString contentType, in AUTF8String data); */
NS_IMETHODIMP nsSimpleMimeConverter::ConvertToHTML(const nsACString & contentType, const nsACString & data, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define NS_SIMPLEMIMECONVERTERS_CATEGORY "simple-mime-converters"

#endif /* __gen_nsISimpleMimeConverter_h__ */
