/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportABDescriptor.idl
 */

#ifndef __gen_nsIImportABDescriptor_h__
#define __gen_nsIImportABDescriptor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */


/* starting interface:    nsIImportABDescriptor */
#define NS_IIMPORTABDESCRIPTOR_IID_STR "9c1774e0-3538-11d3-a206-00a0cc26da63"

#define NS_IIMPORTABDESCRIPTOR_IID \
  {0x9c1774e0, 0x3538, 0x11d3, \
    { 0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63 }}

class NS_NO_VTABLE nsIImportABDescriptor : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMPORTABDESCRIPTOR_IID)

  /* attribute unsigned long identifier; */
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier) = 0;
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier) = 0;

  /* attribute unsigned long ref; */
  NS_IMETHOD GetRef(PRUint32 *aRef) = 0;
  NS_IMETHOD SetRef(PRUint32 aRef) = 0;

  /* attribute unsigned long size; */
  NS_IMETHOD GetSize(PRUint32 *aSize) = 0;
  NS_IMETHOD SetSize(PRUint32 aSize) = 0;

  /* wstring GetPreferredName (); */
  NS_IMETHOD GetPreferredName(PRUnichar **_retval) = 0;

  /* void SetPreferredName ([const] in wstring name); */
  NS_IMETHOD SetPreferredName(const PRUnichar *name) = 0;

  /* readonly attribute nsIFileSpec fileSpec; */
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec) = 0;

  /* attribute boolean import; */
  NS_IMETHOD GetImport(PRBool *aImport) = 0;
  NS_IMETHOD SetImport(PRBool aImport) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTABDESCRIPTOR \
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier); \
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier); \
  NS_IMETHOD GetRef(PRUint32 *aRef); \
  NS_IMETHOD SetRef(PRUint32 aRef); \
  NS_IMETHOD GetSize(PRUint32 *aSize); \
  NS_IMETHOD SetSize(PRUint32 aSize); \
  NS_IMETHOD GetPreferredName(PRUnichar **_retval); \
  NS_IMETHOD SetPreferredName(const PRUnichar *name); \
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec); \
  NS_IMETHOD GetImport(PRBool *aImport); \
  NS_IMETHOD SetImport(PRBool aImport); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTABDESCRIPTOR(_to) \
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier) { return _to GetIdentifier(aIdentifier); } \
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier) { return _to SetIdentifier(aIdentifier); } \
  NS_IMETHOD GetRef(PRUint32 *aRef) { return _to GetRef(aRef); } \
  NS_IMETHOD SetRef(PRUint32 aRef) { return _to SetRef(aRef); } \
  NS_IMETHOD GetSize(PRUint32 *aSize) { return _to GetSize(aSize); } \
  NS_IMETHOD SetSize(PRUint32 aSize) { return _to SetSize(aSize); } \
  NS_IMETHOD GetPreferredName(PRUnichar **_retval) { return _to GetPreferredName(_retval); } \
  NS_IMETHOD SetPreferredName(const PRUnichar *name) { return _to SetPreferredName(name); } \
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec) { return _to GetFileSpec(aFileSpec); } \
  NS_IMETHOD GetImport(PRBool *aImport) { return _to GetImport(aImport); } \
  NS_IMETHOD SetImport(PRBool aImport) { return _to SetImport(aImport); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTABDESCRIPTOR(_to) \
  NS_IMETHOD GetIdentifier(PRUint32 *aIdentifier) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIdentifier(aIdentifier); } \
  NS_IMETHOD SetIdentifier(PRUint32 aIdentifier) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIdentifier(aIdentifier); } \
  NS_IMETHOD GetRef(PRUint32 *aRef) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRef(aRef); } \
  NS_IMETHOD SetRef(PRUint32 aRef) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRef(aRef); } \
  NS_IMETHOD GetSize(PRUint32 *aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSize(aSize); } \
  NS_IMETHOD SetSize(PRUint32 aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSize(aSize); } \
  NS_IMETHOD GetPreferredName(PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPreferredName(_retval); } \
  NS_IMETHOD SetPreferredName(const PRUnichar *name) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPreferredName(name); } \
  NS_IMETHOD GetFileSpec(nsIFileSpec * *aFileSpec) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileSpec(aFileSpec); } \
  NS_IMETHOD GetImport(PRBool *aImport) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImport(aImport); } \
  NS_IMETHOD SetImport(PRBool aImport) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImport(aImport); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportABDescriptor : public nsIImportABDescriptor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTABDESCRIPTOR

  nsImportABDescriptor();

private:
  ~nsImportABDescriptor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportABDescriptor, nsIImportABDescriptor)

nsImportABDescriptor::nsImportABDescriptor()
{
  /* member initializers and constructor code */
}

nsImportABDescriptor::~nsImportABDescriptor()
{
  /* destructor code */
}

/* attribute unsigned long identifier; */
NS_IMETHODIMP nsImportABDescriptor::GetIdentifier(PRUint32 *aIdentifier)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetIdentifier(PRUint32 aIdentifier)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long ref; */
NS_IMETHODIMP nsImportABDescriptor::GetRef(PRUint32 *aRef)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetRef(PRUint32 aRef)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long size; */
NS_IMETHODIMP nsImportABDescriptor::GetSize(PRUint32 *aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetSize(PRUint32 aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetPreferredName (); */
NS_IMETHODIMP nsImportABDescriptor::GetPreferredName(PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetPreferredName ([const] in wstring name); */
NS_IMETHODIMP nsImportABDescriptor::SetPreferredName(const PRUnichar *name)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIFileSpec fileSpec; */
NS_IMETHODIMP nsImportABDescriptor::GetFileSpec(nsIFileSpec * *aFileSpec)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean import; */
NS_IMETHODIMP nsImportABDescriptor::GetImport(PRBool *aImport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetImport(PRBool aImport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

/*
	The default implementation can be obtained from
	nsIImportService::CreateNewABDescriptor();
	
	You should only be interested in using this class if you implement
	the nsIImportAddressBooks interface in which case, just using the service to
	create new ones should work fine for you.  If not, implement your
	own.
*/

#endif /* __gen_nsIImportABDescriptor_h__ */
